/*
 *   Copyright © 2013 Francisco Sariego Rodríguez
 *
 *   $Id: ISBNHyphenAppenderTest.java 23 2013-08-02 14:29:39Z frsarieg $
 *
 *   This file is part of ISBNHyphenAppender.
 *
 *   ISBNHyphenAppender is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   ISBNHyphenAppender is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public License
 *   along with ISBNHyphenAppender.  If not, see <http://www.gnu.org/licenses/>.
 */
package net.sourceforge.isbnhyphenappender;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

/**
 * Tests the {@code ISBNHyphenAppender} class.
 *
 * @author Francisco Sariego Rodríguez
 * @version $Revision: 23 $ $Date: 2009-06-27 13:50:37 +0200 (sáb 27 de jun de
 * 2009) $
 */
public class ISBNHyphenAppenderTest {

    /**
     * ISBN-10s to test.
     */
    private String[] ISBN10s;
    /**
     * ISBN-13s to test.
     */
    private String[] ISBN13s;
    /**
     * {@code ISBNHyphenAppender} instance to test.
     */
    private ISBNHyphenAppender ISBNHyphenAppender;

    public ISBNHyphenAppenderTest() {
    }

    @Before
    public void setUp() {
        //Array of well-hyphenated ISBN-10
        //The checksum number is not well calculed
        this.ISBN13s = new String[]{
            "978-0-00-000000-X",
            "978-0-19-999999-X",
            "978-0-200-00000-X",
            "978-0-699-99999-X",
            "978-0-7000-0000-X",
            "978-0-8499-9999-X",
            "978-0-85000-000-X",
            "978-0-89999-999-X",
            "978-0-900000-00-X",
            "978-0-949999-99-X",
            "978-0-9500000-0-X",
            "978-0-9999999-9-X",
            "978-1-00-000000-X",
            "978-1-09-999999-X",
            "978-1-100-00000-X",
            "978-1-399-99999-X",
            "978-1-4000-0000-X",
            "978-1-5499-9999-X",
            "978-1-55000-000-X",
            "978-1-86979-999-X",
            "978-1-869800-00-X",
            "978-1-998999-99-X",
            "978-1-9990000-0-X",
            "978-1-9999999-9-X",
            "978-2-00-000000-X",
            "978-2-19-999999-X",
            "978-2-200-00000-X",
            "978-2-349-99999-X",
            "978-2-35000-000-X",
            "978-2-39999-999-X",
            "978-2-400-00000-X",
            "978-2-699-99999-X",
            "978-2-7000-0000-X",
            "978-2-8399-9999-X",
            "978-2-84000-000-X",
            "978-2-89999-999-X",
            "978-2-900000-00-X",
            "978-2-949999-99-X",
            "978-2-9500000-0-X",
            "978-2-9999999-9-X",
            "978-3-00-000000-X",
            "978-3-02-999999-X",
            "978-3-030-00000-X",
            "978-3-033-99999-X",
            "978-3-0340-0000-X",
            "978-3-0369-9999-X",
            "978-3-03700-000-X",
            "978-3-03999-999-X",
            "978-3-04-000000-X",
            "978-3-19-999999-X",
            "978-3-200-00000-X",
            "978-3-699-99999-X",
            "978-3-7000-0000-X",
            "978-3-8499-9999-X",
            "978-3-85000-000-X",
            "978-3-89999-999-X",
            "978-3-900000-00-X",
            "978-3-949999-99-X",
            "978-3-9500000-0-X",
            "978-3-9539999-9-X",
            "978-3-95400-000-X",
            "978-3-96999-999-X",
            "978-3-9700000-0-X",
            "978-3-9899999-9-X",
            "978-3-99000-000-X",
            "978-3-99499-999-X",
            "978-3-99500-000-X",
            "978-3-99999-999-X",
            "978-4-00-000000-X",
            "978-4-19-999999-X",
            "978-4-200-00000-X",
            "978-4-699-99999-X",
            "978-4-7000-0000-X",
            "978-4-8499-9999-X",
            "978-4-85000-000-X",
            "978-4-89999-999-X",
            "978-4-900000-00-X",
            "978-4-949999-99-X",
            "978-4-9500000-0-X",
            "978-4-9999999-9-X",
            "978-5-00000-000-X",
            "978-5-00499-999-X",
            "978-5-0050-0000-X",
            "978-5-0099-9999-X",
            "978-5-01-000000-X",
            "978-5-19-999999-X",
            "978-5-200-00000-X",
            "978-5-420-99999-X",
            "978-5-4210-0000-X",
            "978-5-4299-9999-X",
            "978-5-430-00000-X",
            "978-5-430-99999-X",
            "978-5-4310-0000-X",
            "978-5-4399-9999-X",
            "978-5-440-00000-X",
            "978-5-440-99999-X",
            "978-5-4410-0000-X",
            "978-5-4499-9999-X",
            "978-5-450-00000-X",
            "978-5-699-99999-X",
            "978-5-7000-0000-X",
            "978-5-8499-9999-X",
            "978-5-85000-000-X",
            "978-5-89999-999-X",
            "978-5-900000-00-X",
            "978-5-909999-99-X",
            "978-5-91000-000-X",
            "978-5-91999-999-X",
            "978-5-9200-0000-X",
            "978-5-9299-9999-X",
            "978-5-93000-000-X",
            "978-5-94999-999-X",
            "978-5-9500000-0-X",
            "978-5-9500999-9-X",
            "978-5-9501-0000-X",
            "978-5-9799-9999-X",
            "978-5-98000-000-X",
            "978-5-98999-999-X",
            "978-5-9900000-0-X",
            "978-5-9909999-9-X",
            "978-5-9910-0000-X",
            "978-5-9999-9999-X",
            "978-600-00-0000-X",
            "978-600-09-9999-X",
            "978-600-100-000-X",
            "978-600-499-999-X",
            "978-600-5000-00-X",
            "978-600-8999-99-X",
            "978-600-90000-0-X",
            "978-600-99999-9-X",
            "978-601-00-0000-X",
            "978-601-19-9999-X",
            "978-601-200-000-X",
            "978-601-699-999-X",
            "978-601-7000-00-X",
            "978-601-7999-99-X",
            "978-601-80000-0-X",
            "978-601-84999-9-X",
            "978-601-85-0000-X",
            "978-601-99-9999-X",
            "978-602-00-0000-X",
            "978-602-13-9999-X",
            "978-602-14000-0-X",
            "978-602-14999-9-X",
            "978-602-1500-00-X",
            "978-602-1699-99-X",
            "978-602-17000-0-X",
            "978-602-17999-9-X",
            "978-602-18000-0-X",
            "978-602-18999-9-X",
            "978-602-19000-0-X",
            "978-602-19999-9-X",
            "978-602-200-000-X",
            "978-602-749-999-X",
            "978-602-7500-00-X",
            "978-602-7999-99-X",
            "978-602-8000-00-X",
            "978-602-9499-99-X",
            "978-602-95000-0-X",
            "978-602-99999-9-X",
            "978-603-00-0000-X",
            "978-603-04-9999-X",
            "978-603-05-0000-X",
            "978-603-49-9999-X",
            "978-603-500-000-X",
            "978-603-799-999-X",
            "978-603-8000-00-X",
            "978-603-8999-99-X",
            "978-603-90000-0-X",
            "978-603-99999-9-X",
            "978-604-0-00000-X",
            "978-604-4-99999-X",
            "978-604-50-0000-X",
            "978-604-89-9999-X",
            "978-604-900-000-X",
            "978-604-979-999-X",
            "978-604-9800-00-X",
            "978-604-9999-99-X",
            "978-605-01-0000-X",
            "978-605-09-9999-X",
            "978-605-100-000-X",
            "978-605-399-999-X",
            "978-605-4000-00-X",
            "978-605-5999-99-X",
            "978-605-60000-0-X",
            "978-605-89999-9-X",
            "978-605-90-0000-X",
            "978-605-99-9999-X",
            "978-606-0-00000-X",
            "978-606-0-99999-X",
            "978-606-10-0000-X",
            "978-606-49-9999-X",
            "978-606-500-000-X",
            "978-606-799-999-X",
            "978-606-8000-00-X",
            "978-606-9199-99-X",
            "978-606-92000-0-X",
            "978-606-99999-9-X",
            "978-607-00-0000-X",
            "978-607-39-9999-X",
            "978-607-400-000-X",
            "978-607-749-999-X",
            "978-607-7500-00-X",
            "978-607-9499-99-X",
            "978-607-95000-0-X",
            "978-607-99999-9-X",
            "978-608-0-00000-X",
            "978-608-0-99999-X",
            "978-608-10-0000-X",
            "978-608-19-9999-X",
            "978-608-200-000-X",
            "978-608-449-999-X",
            "978-608-4500-00-X",
            "978-608-6499-99-X",
            "978-608-65000-0-X",
            "978-608-69999-9-X",
            "978-608-7-00000-X",
            "978-608-9-99999-X",
            "978-609-00-0000-X",
            "978-609-39-9999-X",
            "978-609-400-000-X",
            "978-609-799-999-X",
            "978-609-8000-00-X",
            "978-609-9499-99-X",
            "978-609-95000-0-X",
            "978-609-99999-9-X",
            "978-612-00-0000-X",
            "978-612-29-9999-X",
            "978-612-300-000-X",
            "978-612-399-999-X",
            "978-612-4000-00-X",
            "978-612-4499-99-X",
            "978-612-45000-0-X",
            "978-612-49999-9-X",
            "978-612-50-0000-X",
            "978-612-99-9999-X",
            "978-613-0-00000-X",
            "978-613-9-99999-X",
            "978-614-00-0000-X",
            "978-614-39-9999-X",
            "978-614-400-000-X",
            "978-614-799-999-X",
            "978-614-8000-00-X",
            "978-614-9499-99-X",
            "978-614-95000-0-X",
            "978-614-99999-9-X",
            "978-615-00-0000-X",
            "978-615-09-9999-X",
            "978-615-100-000-X",
            "978-615-499-999-X",
            "978-615-5000-00-X",
            "978-615-7999-99-X",
            "978-615-80000-0-X",
            "978-615-89999-9-X",
            "978-616-00-0000-X",
            "978-616-19-9999-X",
            "978-616-200-000-X",
            "978-616-699-999-X",
            "978-616-7000-00-X",
            "978-616-8999-99-X",
            "978-616-90000-0-X",
            "978-616-99999-9-X",
            "978-617-00-0000-X",
            "978-617-49-9999-X",
            "978-617-500-000-X",
            "978-617-699-999-X",
            "978-617-7000-00-X",
            "978-617-8999-99-X",
            "978-617-90000-0-X",
            "978-617-99999-9-X",
            "978-618-00-0000-X",
            "978-618-19-9999-X",
            "978-618-200-000-X",
            "978-618-499-999-X",
            "978-618-5000-00-X",
            "978-618-7999-99-X",
            "978-618-80000-0-X",
            "978-618-99999-9-X",
            "978-619-00-0000-X",
            "978-619-14-9999-X",
            "978-619-150-000-X",
            "978-619-699-999-X",
            "978-619-7000-00-X",
            "978-619-8999-99-X",
            "978-619-90000-0-X",
            "978-619-99999-9-X",
            "978-620-0-00000-X",
            "978-620-9-99999-X",
            "978-621-00-0000-X",
            "978-621-29-9999-X",
            "978-621-400-000-X",
            "978-621-599-999-X",
            "978-621-8000-00-X",
            "978-621-8999-99-X",
            "978-621-95000-0-X",
            "978-621-99999-9-X",
            "978-7-00-000000-X",
            "978-7-09-999999-X",
            "978-7-100-00000-X",
            "978-7-499-99999-X",
            "978-7-5000-0000-X",
            "978-7-7999-9999-X",
            "978-7-80000-000-X",
            "978-7-89999-999-X",
            "978-7-900000-00-X",
            "978-7-999999-99-X",
            "978-80-00-00000-X",
            "978-80-19-99999-X",
            "978-80-200-0000-X",
            "978-80-699-9999-X",
            "978-80-7000-000-X",
            "978-80-8499-999-X",
            "978-80-85000-00-X",
            "978-80-89999-99-X",
            "978-80-900000-0-X",
            "978-80-999999-9-X",
            "978-81-00-00000-X",
            "978-81-19-99999-X",
            "978-81-200-0000-X",
            "978-81-699-9999-X",
            "978-81-7000-000-X",
            "978-81-8499-999-X",
            "978-81-85000-00-X",
            "978-81-89999-99-X",
            "978-81-900000-0-X",
            "978-81-999999-9-X",
            "978-82-00-00000-X",
            "978-82-19-99999-X",
            "978-82-200-0000-X",
            "978-82-699-9999-X",
            "978-82-7000-000-X",
            "978-82-8999-999-X",
            "978-82-90000-00-X",
            "978-82-98999-99-X",
            "978-82-990000-0-X",
            "978-82-999999-9-X",
            "978-83-00-00000-X",
            "978-83-19-99999-X",
            "978-83-200-0000-X",
            "978-83-599-9999-X",
            "978-83-60000-00-X",
            "978-83-69999-99-X",
            "978-83-7000-000-X",
            "978-83-8499-999-X",
            "978-83-85000-00-X",
            "978-83-89999-99-X",
            "978-83-900000-0-X",
            "978-83-999999-9-X",
            "978-84-00-00000-X",
            "978-84-13-99999-X",
            "978-84-140-0000-X",
            "978-84-149-9999-X",
            "978-84-15000-00-X",
            "978-84-19999-99-X",
            "978-84-200-0000-X",
            "978-84-699-9999-X",
            "978-84-7000-000-X",
            "978-84-8499-999-X",
            "978-84-85000-00-X",
            "978-84-89999-99-X",
            "978-84-9000-000-X",
            "978-84-9199-999-X",
            "978-84-920000-0-X",
            "978-84-923999-9-X",
            "978-84-92400-00-X",
            "978-84-92999-99-X",
            "978-84-930000-0-X",
            "978-84-949999-9-X",
            "978-84-95000-00-X",
            "978-84-96999-99-X",
            "978-84-9700-000-X",
            "978-84-9999-999-X",
            "978-85-00-00000-X",
            "978-85-19-99999-X",
            "978-85-200-0000-X",
            "978-85-599-9999-X",
            "978-85-60000-00-X",
            "978-85-69999-99-X",
            "978-85-7000-000-X",
            "978-85-8499-999-X",
            "978-85-85000-00-X",
            "978-85-89999-99-X",
            "978-85-900000-0-X",
            "978-85-979999-9-X",
            "978-85-98000-00-X",
            "978-85-99999-99-X",
            "978-86-00-00000-X",
            "978-86-29-99999-X",
            "978-86-300-0000-X",
            "978-86-599-9999-X",
            "978-86-6000-000-X",
            "978-86-7999-999-X",
            "978-86-80000-00-X",
            "978-86-89999-99-X",
            "978-86-900000-0-X",
            "978-86-999999-9-X",
            "978-87-00-00000-X",
            "978-87-29-99999-X",
            "978-87-400-0000-X",
            "978-87-649-9999-X",
            "978-87-7000-000-X",
            "978-87-7999-999-X",
            "978-87-85000-00-X",
            "978-87-94999-99-X",
            "978-87-970000-0-X",
            "978-87-999999-9-X",
            "978-88-00-00000-X",
            "978-88-19-99999-X",
            "978-88-200-0000-X",
            "978-88-599-9999-X",
            "978-88-6000-000-X",
            "978-88-8499-999-X",
            "978-88-85000-00-X",
            "978-88-89999-99-X",
            "978-88-900000-0-X",
            "978-88-909999-9-X",
            "978-88-910-0000-X",
            "978-88-929-9999-X",
            "978-88-9300-000-X",
            "978-88-9399-999-X",
            "978-88-940000-0-X",
            "978-88-949999-9-X",
            "978-88-95000-00-X",
            "978-88-99999-99-X",
            "978-89-00-00000-X",
            "978-89-24-99999-X",
            "978-89-250-0000-X",
            "978-89-549-9999-X",
            "978-89-5500-000-X",
            "978-89-8499-999-X",
            "978-89-85000-00-X",
            "978-89-94999-99-X",
            "978-89-950000-0-X",
            "978-89-969999-9-X",
            "978-89-97000-00-X",
            "978-89-98999-99-X",
            "978-89-990-0000-X",
            "978-89-999-9999-X",
            "978-90-00-00000-X",
            "978-90-19-99999-X",
            "978-90-200-0000-X",
            "978-90-499-9999-X",
            "978-90-5000-000-X",
            "978-90-6999-999-X",
            "978-90-70000-00-X",
            "978-90-79999-99-X",
            "978-90-800000-0-X",
            "978-90-849999-9-X",
            "978-90-8500-000-X",
            "978-90-8999-999-X",
            "978-90-90-00000-X",
            "978-90-90-99999-X",
            "978-90-94-00000-X",
            "978-90-94-99999-X",
            "978-91-0-000000-X",
            "978-91-1-999999-X",
            "978-91-20-00000-X",
            "978-91-49-99999-X",
            "978-91-500-0000-X",
            "978-91-649-9999-X",
            "978-91-7000-000-X",
            "978-91-7999-999-X",
            "978-91-85000-00-X",
            "978-91-94999-99-X",
            "978-91-970000-0-X",
            "978-91-999999-9-X",
            "978-92-0-000000-X",
            "978-92-5-999999-X",
            "978-92-60-00000-X",
            "978-92-79-99999-X",
            "978-92-800-0000-X",
            "978-92-899-9999-X",
            "978-92-9000-000-X",
            "978-92-9499-999-X",
            "978-92-95000-00-X",
            "978-92-98999-99-X",
            "978-92-990000-0-X",
            "978-92-999999-9-X",
            "978-93-00-00000-X",
            "978-93-09-99999-X",
            "978-93-100-0000-X",
            "978-93-499-9999-X",
            "978-93-5000-000-X",
            "978-93-7999-999-X",
            "978-93-80000-00-X",
            "978-93-94999-99-X",
            "978-93-950000-0-X",
            "978-93-999999-9-X",
            "978-94-000-0000-X",
            "978-94-599-9999-X",
            "978-94-6000-000-X",
            "978-94-8999-999-X",
            "978-94-90000-00-X",
            "978-94-99999-99-X",
            "978-950-00-0000-X",
            "978-950-49-9999-X",
            "978-950-500-000-X",
            "978-950-899-999-X",
            "978-950-9000-00-X",
            "978-950-9899-99-X",
            "978-950-99000-0-X",
            "978-950-99999-9-X",
            "978-951-0-00000-X",
            "978-951-1-99999-X",
            "978-951-20-0000-X",
            "978-951-54-9999-X",
            "978-951-550-000-X",
            "978-951-889-999-X",
            "978-951-8900-00-X",
            "978-951-9499-99-X",
            "978-951-95000-0-X",
            "978-951-99999-9-X",
            "978-952-00-0000-X",
            "978-952-19-9999-X",
            "978-952-200-000-X",
            "978-952-499-999-X",
            "978-952-5000-00-X",
            "978-952-5999-99-X",
            "978-952-60-0000-X",
            "978-952-65-9999-X",
            "978-952-6600-00-X",
            "978-952-6699-99-X",
            "978-952-67000-0-X",
            "978-952-69999-9-X",
            "978-952-7000-00-X",
            "978-952-7999-99-X",
            "978-952-80-0000-X",
            "978-952-94-9999-X",
            "978-952-9500-00-X",
            "978-952-9899-99-X",
            "978-952-99000-0-X",
            "978-952-99999-9-X",
            "978-953-0-00000-X",
            "978-953-0-99999-X",
            "978-953-10-0000-X",
            "978-953-14-9999-X",
            "978-953-150-000-X",
            "978-953-509-999-X",
            "978-953-51-0000-X",
            "978-953-54-9999-X",
            "978-953-55000-0-X",
            "978-953-59999-9-X",
            "978-953-6000-00-X",
            "978-953-9499-99-X",
            "978-953-95000-0-X",
            "978-953-99999-9-X",
            "978-954-00-0000-X",
            "978-954-28-9999-X",
            "978-954-2900-00-X",
            "978-954-2999-99-X",
            "978-954-300-000-X",
            "978-954-799-999-X",
            "978-954-8000-00-X",
            "978-954-8999-99-X",
            "978-954-90000-0-X",
            "978-954-92999-9-X",
            "978-954-9300-00-X",
            "978-954-9999-99-X",
            "978-955-0000-00-X",
            "978-955-1999-99-X",
            "978-955-20-0000-X",
            "978-955-43-9999-X",
            "978-955-44000-0-X",
            "978-955-44999-9-X",
            "978-955-4500-00-X",
            "978-955-4999-99-X",
            "978-955-50000-0-X",
            "978-955-54999-9-X",
            "978-955-550-000-X",
            "978-955-799-999-X",
            "978-955-8000-00-X",
            "978-955-9499-99-X",
            "978-955-95000-0-X",
            "978-955-99999-9-X",
            "978-956-00-0000-X",
            "978-956-19-9999-X",
            "978-956-200-000-X",
            "978-956-699-999-X",
            "978-956-7000-00-X",
            "978-956-9999-99-X",
            "978-957-00-0000-X",
            "978-957-02-9999-X",
            "978-957-0300-00-X",
            "978-957-0499-99-X",
            "978-957-05-0000-X",
            "978-957-19-9999-X",
            "978-957-2000-00-X",
            "978-957-2099-99-X",
            "978-957-21-0000-X",
            "978-957-27-9999-X",
            "978-957-28000-0-X",
            "978-957-30999-9-X",
            "978-957-31-0000-X",
            "978-957-43-9999-X",
            "978-957-440-000-X",
            "978-957-819-999-X",
            "978-957-8200-00-X",
            "978-957-9699-99-X",
            "978-957-97000-0-X",
            "978-957-99999-9-X",
            "978-958-00-0000-X",
            "978-958-56-9999-X",
            "978-958-57000-0-X",
            "978-958-59999-9-X",
            "978-958-600-000-X",
            "978-958-799-999-X",
            "978-958-8000-00-X",
            "978-958-9499-99-X",
            "978-958-95000-0-X",
            "978-958-99999-9-X",
            "978-959-00-0000-X",
            "978-959-19-9999-X",
            "978-959-200-000-X",
            "978-959-699-999-X",
            "978-959-7000-00-X",
            "978-959-8499-99-X",
            "978-959-85000-0-X",
            "978-959-99999-9-X",
            "978-960-00-0000-X",
            "978-960-19-9999-X",
            "978-960-200-000-X",
            "978-960-659-999-X",
            "978-960-6600-00-X",
            "978-960-6899-99-X",
            "978-960-690-000-X",
            "978-960-699-999-X",
            "978-960-7000-00-X",
            "978-960-8499-99-X",
            "978-960-85000-0-X",
            "978-960-92999-9-X",
            "978-960-93-0000-X",
            "978-960-93-9999-X",
            "978-960-9400-00-X",
            "978-960-9799-99-X",
            "978-960-98000-0-X",
            "978-960-99999-9-X",
            "978-961-00-0000-X",
            "978-961-19-9999-X",
            "978-961-200-000-X",
            "978-961-599-999-X",
            "978-961-6000-00-X",
            "978-961-8999-99-X",
            "978-961-90000-0-X",
            "978-961-94999-9-X",
            "978-962-00-0000-X",
            "978-962-19-9999-X",
            "978-962-200-000-X",
            "978-962-699-999-X",
            "978-962-7000-00-X",
            "978-962-8499-99-X",
            "978-962-85000-0-X",
            "978-962-86999-9-X",
            "978-962-8700-00-X",
            "978-962-8999-99-X",
            "978-962-900-000-X",
            "978-962-999-999-X",
            "978-963-00-0000-X",
            "978-963-19-9999-X",
            "978-963-200-000-X",
            "978-963-699-999-X",
            "978-963-7000-00-X",
            "978-963-8499-99-X",
            "978-963-85000-0-X",
            "978-963-89999-9-X",
            "978-963-9000-00-X",
            "978-963-9999-99-X",
            "978-964-00-0000-X",
            "978-964-14-9999-X",
            "978-964-150-000-X",
            "978-964-249-999-X",
            "978-964-2500-00-X",
            "978-964-2999-99-X",
            "978-964-300-000-X",
            "978-964-549-999-X",
            "978-964-5500-00-X",
            "978-964-8999-99-X",
            "978-964-90000-0-X",
            "978-964-96999-9-X",
            "978-964-970-000-X",
            "978-964-989-999-X",
            "978-964-9900-00-X",
            "978-964-9999-99-X",
            "978-965-00-0000-X",
            "978-965-19-9999-X",
            "978-965-200-000-X",
            "978-965-599-999-X",
            "978-965-7000-00-X",
            "978-965-7999-99-X",
            "978-965-90000-0-X",
            "978-965-99999-9-X",
            "978-966-00-0000-X",
            "978-966-12-9999-X",
            "978-966-130-000-X",
            "978-966-139-999-X",
            "978-966-14-0000-X",
            "978-966-14-9999-X",
            "978-966-1500-00-X",
            "978-966-1699-99-X",
            "978-966-170-000-X",
            "978-966-199-999-X",
            "978-966-2000-00-X",
            "978-966-2789-99-X",
            "978-966-279-000-X",
            "978-966-289-999-X",
            "978-966-2900-00-X",
            "978-966-2999-99-X",
            "978-966-300-000-X",
            "978-966-699-999-X",
            "978-966-7000-00-X",
            "978-966-8999-99-X",
            "978-966-90000-0-X",
            "978-966-90999-9-X",
            "978-966-910-000-X",
            "978-966-949-999-X",
            "978-966-95000-0-X",
            "978-966-97999-9-X",
            "978-966-980-000-X",
            "978-966-999-999-X",
            "978-967-00-0000-X",
            "978-967-00-9999-X",
            "978-967-0100-00-X",
            "978-967-0999-99-X",
            "978-967-10000-0-X",
            "978-967-19999-9-X",
            "978-967-300-000-X",
            "978-967-499-999-X",
            "978-967-5000-00-X",
            "978-967-5999-99-X",
            "978-967-60-0000-X",
            "978-967-89-9999-X",
            "978-967-900-000-X",
            "978-967-989-999-X",
            "978-967-9900-00-X",
            "978-967-9989-99-X",
            "978-967-99900-0-X",
            "978-967-99999-9-X",
            "978-968-01-0000-X",
            "978-968-39-9999-X",
            "978-968-400-000-X",
            "978-968-499-999-X",
            "978-968-5000-00-X",
            "978-968-7999-99-X",
            "978-968-800-000-X",
            "978-968-899-999-X",
            "978-968-9000-00-X",
            "978-968-9999-99-X",
            "978-969-0-00000-X",
            "978-969-1-99999-X",
            "978-969-20-0000-X",
            "978-969-39-9999-X",
            "978-969-400-000-X",
            "978-969-799-999-X",
            "978-969-8000-00-X",
            "978-969-9999-99-X",
            "978-970-01-0000-X",
            "978-970-59-9999-X",
            "978-970-600-000-X",
            "978-970-899-999-X",
            "978-970-9000-00-X",
            "978-970-9099-99-X",
            "978-970-91000-0-X",
            "978-970-96999-9-X",
            "978-970-9700-00-X",
            "978-970-9999-99-X",
            "978-971-000-000-X",
            "978-971-015-999-X",
            "978-971-0160-00-X",
            "978-971-0199-99-X",
            "978-971-02-0000-X",
            "978-971-02-9999-X",
            "978-971-0300-00-X",
            "978-971-0599-99-X",
            "978-971-06-0000-X",
            "978-971-49-9999-X",
            "978-971-500-000-X",
            "978-971-849-999-X",
            "978-971-8500-00-X",
            "978-971-9099-99-X",
            "978-971-91000-0-X",
            "978-971-95999-9-X",
            "978-971-9600-00-X",
            "978-971-9699-99-X",
            "978-971-97-0000-X",
            "978-971-98-9999-X",
            "978-971-9900-00-X",
            "978-971-9999-99-X",
            "978-972-0-00000-X",
            "978-972-1-99999-X",
            "978-972-20-0000-X",
            "978-972-54-9999-X",
            "978-972-550-000-X",
            "978-972-799-999-X",
            "978-972-8000-00-X",
            "978-972-9499-99-X",
            "978-972-95000-0-X",
            "978-972-99999-9-X",
            "978-973-0-00000-X",
            "978-973-0-99999-X",
            "978-973-100-000-X",
            "978-973-169-999-X",
            "978-973-1700-00-X",
            "978-973-1999-99-X",
            "978-973-20-0000-X",
            "978-973-54-9999-X",
            "978-973-550-000-X",
            "978-973-759-999-X",
            "978-973-7600-00-X",
            "978-973-8499-99-X",
            "978-973-85000-0-X",
            "978-973-88999-9-X",
            "978-973-8900-00-X",
            "978-973-9499-99-X",
            "978-973-95000-0-X",
            "978-973-99999-9-X",
            "978-974-00-0000-X",
            "978-974-19-9999-X",
            "978-974-200-000-X",
            "978-974-699-999-X",
            "978-974-7000-00-X",
            "978-974-8499-99-X",
            "978-974-85000-0-X",
            "978-974-89999-9-X",
            "978-974-90000-0-X",
            "978-974-94999-9-X",
            "978-974-9500-00-X",
            "978-974-9999-99-X",
            "978-975-00000-0-X",
            "978-975-01999-9-X",
            "978-975-02-0000-X",
            "978-975-24-9999-X",
            "978-975-250-000-X",
            "978-975-599-999-X",
            "978-975-6000-00-X",
            "978-975-9199-99-X",
            "978-975-92000-0-X",
            "978-975-98999-9-X",
            "978-975-990-000-X",
            "978-975-999-999-X",
            "978-976-0-00000-X",
            "978-976-3-99999-X",
            "978-976-40-0000-X",
            "978-976-59-9999-X",
            "978-976-600-000-X",
            "978-976-799-999-X",
            "978-976-8000-00-X",
            "978-976-9499-99-X",
            "978-976-95000-0-X",
            "978-976-99999-9-X",
            "978-977-00-0000-X",
            "978-977-19-9999-X",
            "978-977-200-000-X",
            "978-977-499-999-X",
            "978-977-5000-00-X",
            "978-977-6999-99-X",
            "978-977-700-000-X",
            "978-977-849-999-X",
            "978-977-85000-0-X",
            "978-977-89999-9-X",
            "978-977-90-0000-X",
            "978-977-99-9999-X",
            "978-978-000-000-X",
            "978-978-199-999-X",
            "978-978-2000-00-X",
            "978-978-2999-99-X",
            "978-978-30000-0-X",
            "978-978-79999-9-X",
            "978-978-8000-00-X",
            "978-978-8999-99-X",
            "978-978-900-000-X",
            "978-978-999-999-X",
            "978-979-000-000-X",
            "978-979-099-999-X",
            "978-979-1000-00-X",
            "978-979-1499-99-X",
            "978-979-15000-0-X",
            "978-979-19999-9-X",
            "978-979-20-0000-X",
            "978-979-29-9999-X",
            "978-979-3000-00-X",
            "978-979-3999-99-X",
            "978-979-400-000-X",
            "978-979-799-999-X",
            "978-979-8000-00-X",
            "978-979-9499-99-X",
            "978-979-95000-0-X",
            "978-979-99999-9-X",
            "978-980-00-0000-X",
            "978-980-19-9999-X",
            "978-980-200-000-X",
            "978-980-599-999-X",
            "978-980-6000-00-X",
            "978-980-9999-99-X",
            "978-981-00-0000-X",
            "978-981-11-9999-X",
            "978-981-200-000-X",
            "978-981-289-999-X",
            "978-981-290-000-X",
            "978-981-299-999-X",
            "978-981-3000-00-X",
            "978-981-3099-99-X",
            "978-981-310-000-X",
            "978-981-399-999-X",
            "978-981-4000-00-X",
            "978-981-9999-99-X",
            "978-982-00-0000-X",
            "978-982-09-9999-X",
            "978-982-100-000-X",
            "978-982-699-999-X",
            "978-982-70-0000-X",
            "978-982-89-9999-X",
            "978-982-9000-00-X",
            "978-982-9799-99-X",
            "978-982-98000-0-X",
            "978-982-99999-9-X",
            "978-983-00-0000-X",
            "978-983-01-9999-X",
            "978-983-020-000-X",
            "978-983-199-999-X",
            "978-983-2000-00-X",
            "978-983-3999-99-X",
            "978-983-40000-0-X",
            "978-983-44999-9-X",
            "978-983-45-0000-X",
            "978-983-49-9999-X",
            "978-983-50-0000-X",
            "978-983-79-9999-X",
            "978-983-800-000-X",
            "978-983-899-999-X",
            "978-983-9000-00-X",
            "978-983-9899-99-X",
            "978-983-99000-0-X",
            "978-983-99999-9-X",
            "978-984-00-0000-X",
            "978-984-39-9999-X",
            "978-984-400-000-X",
            "978-984-799-999-X",
            "978-984-8000-00-X",
            "978-984-8999-99-X",
            "978-984-90000-0-X",
            "978-984-99999-9-X",
            "978-985-00-0000-X",
            "978-985-39-9999-X",
            "978-985-400-000-X",
            "978-985-599-999-X",
            "978-985-6000-00-X",
            "978-985-8999-99-X",
            "978-985-90000-0-X",
            "978-985-99999-9-X",
            "978-986-00-0000-X",
            "978-986-11-9999-X",
            "978-986-120-000-X",
            "978-986-559-999-X",
            "978-986-5600-00-X",
            "978-986-7999-99-X",
            "978-986-80000-0-X",
            "978-986-99999-9-X",
            "978-987-00-0000-X",
            "978-987-09-9999-X",
            "978-987-1000-00-X",
            "978-987-1999-99-X",
            "978-987-20000-0-X",
            "978-987-29999-9-X",
            "978-987-30-0000-X",
            "978-987-35-9999-X",
            "978-987-3600-00-X",
            "978-987-3999-99-X",
            "978-987-40-0000-X",
            "978-987-44-9999-X",
            "978-987-45000-0-X",
            "978-987-49999-9-X",
            "978-987-500-000-X",
            "978-987-899-999-X",
            "978-987-9000-00-X",
            "978-987-9499-99-X",
            "978-987-95000-0-X",
            "978-987-99999-9-X",
            "978-988-00-0000-X",
            "978-988-11-9999-X",
            "978-988-12000-0-X",
            "978-988-14999-9-X",
            "978-988-15000-0-X",
            "978-988-16999-9-X",
            "978-988-17000-0-X",
            "978-988-19999-9-X",
            "978-988-200-000-X",
            "978-988-799-999-X",
            "978-988-8000-00-X",
            "978-988-9699-99-X",
            "978-988-97000-0-X",
            "978-988-99999-9-X",
            "978-989-0-00000-X",
            "978-989-1-99999-X",
            "978-989-20-0000-X",
            "978-989-54-9999-X",
            "978-989-550-000-X",
            "978-989-799-999-X",
            "978-989-8000-00-X",
            "978-989-9499-99-X",
            "978-989-95000-0-X",
            "978-989-99999-9-X",
            "978-9927-00-000-X",
            "978-9927-09-999-X",
            "978-9927-100-00-X",
            "978-9927-399-99-X",
            "978-9927-4000-0-X",
            "978-9927-4999-9-X",
            "978-9928-00-000-X",
            "978-9928-09-999-X",
            "978-9928-100-00-X",
            "978-9928-399-99-X",
            "978-9928-4000-0-X",
            "978-9928-4999-9-X",
            "978-9929-0-0000-X",
            "978-9929-3-9999-X",
            "978-9929-40-000-X",
            "978-9929-54-999-X",
            "978-9929-550-00-X",
            "978-9929-799-99-X",
            "978-9929-8000-0-X",
            "978-9929-9999-9-X",
            "978-9930-00-000-X",
            "978-9930-49-999-X",
            "978-9930-500-00-X",
            "978-9930-939-99-X",
            "978-9930-9400-0-X",
            "978-9930-9999-9-X",
            "978-9931-00-000-X",
            "978-9931-29-999-X",
            "978-9931-300-00-X",
            "978-9931-899-99-X",
            "978-9931-9000-0-X",
            "978-9931-9999-9-X",
            "978-9932-00-000-X",
            "978-9932-39-999-X",
            "978-9932-400-00-X",
            "978-9932-849-99-X",
            "978-9932-8500-0-X",
            "978-9932-9999-9-X",
            "978-9933-0-0000-X",
            "978-9933-0-9999-X",
            "978-9933-10-000-X",
            "978-9933-39-999-X",
            "978-9933-400-00-X",
            "978-9933-899-99-X",
            "978-9933-9000-0-X",
            "978-9933-9999-9-X",
            "978-9934-0-0000-X",
            "978-9934-0-9999-X",
            "978-9934-10-000-X",
            "978-9934-49-999-X",
            "978-9934-500-00-X",
            "978-9934-799-99-X",
            "978-9934-8000-0-X",
            "978-9934-9999-9-X",
            "978-9935-0-0000-X",
            "978-9935-0-9999-X",
            "978-9935-10-000-X",
            "978-9935-39-999-X",
            "978-9935-400-00-X",
            "978-9935-899-99-X",
            "978-9935-9000-0-X",
            "978-9935-9999-9-X",
            "978-9936-0-0000-X",
            "978-9936-1-9999-X",
            "978-9936-20-000-X",
            "978-9936-39-999-X",
            "978-9936-400-00-X",
            "978-9936-799-99-X",
            "978-9936-8000-0-X",
            "978-9936-9999-9-X",
            "978-9937-0-0000-X",
            "978-9937-2-9999-X",
            "978-9937-30-000-X",
            "978-9937-49-999-X",
            "978-9937-500-00-X",
            "978-9937-799-99-X",
            "978-9937-8000-0-X",
            "978-9937-9999-9-X",
            "978-9938-00-000-X",
            "978-9938-79-999-X",
            "978-9938-800-00-X",
            "978-9938-949-99-X",
            "978-9938-9500-0-X",
            "978-9938-9999-9-X",
            "978-9939-0-0000-X",
            "978-9939-4-9999-X",
            "978-9939-50-000-X",
            "978-9939-79-999-X",
            "978-9939-800-00-X",
            "978-9939-899-99-X",
            "978-9939-9000-0-X",
            "978-9939-9999-9-X",
            "978-9940-0-0000-X",
            "978-9940-1-9999-X",
            "978-9940-20-000-X",
            "978-9940-49-999-X",
            "978-9940-500-00-X",
            "978-9940-899-99-X",
            "978-9940-9000-0-X",
            "978-9940-9999-9-X",
            "978-9941-0-0000-X",
            "978-9941-0-9999-X",
            "978-9941-10-000-X",
            "978-9941-39-999-X",
            "978-9941-400-00-X",
            "978-9941-899-99-X",
            "978-9941-9000-0-X",
            "978-9941-9999-9-X",
            "978-9942-00-000-X",
            "978-9942-89-999-X",
            "978-9942-900-00-X",
            "978-9942-984-99-X",
            "978-9942-9850-0-X",
            "978-9942-9999-9-X",
            "978-9943-00-000-X",
            "978-9943-29-999-X",
            "978-9943-300-00-X",
            "978-9943-399-99-X",
            "978-9943-4000-0-X",
            "978-9943-9999-9-X",
            "978-9944-0000-0-X",
            "978-9944-0999-9-X",
            "978-9944-100-00-X",
            "978-9944-499-99-X",
            "978-9944-5000-0-X",
            "978-9944-5999-9-X",
            "978-9944-60-000-X",
            "978-9944-69-999-X",
            "978-9944-700-00-X",
            "978-9944-799-99-X",
            "978-9944-80-000-X",
            "978-9944-89-999-X",
            "978-9944-900-00-X",
            "978-9944-999-99-X",
            "978-9945-00-000-X",
            "978-9945-00-999-X",
            "978-9945-010-00-X",
            "978-9945-079-99-X",
            "978-9945-08-000-X",
            "978-9945-39-999-X",
            "978-9945-400-00-X",
            "978-9945-569-99-X",
            "978-9945-57-000-X",
            "978-9945-57-999-X",
            "978-9945-580-00-X",
            "978-9945-849-99-X",
            "978-9945-8500-0-X",
            "978-9945-9999-9-X",
            "978-9946-0-0000-X",
            "978-9946-1-9999-X",
            "978-9946-20-000-X",
            "978-9946-39-999-X",
            "978-9946-400-00-X",
            "978-9946-899-99-X",
            "978-9946-9000-0-X",
            "978-9946-9999-9-X",
            "978-9947-0-0000-X",
            "978-9947-1-9999-X",
            "978-9947-20-000-X",
            "978-9947-79-999-X",
            "978-9947-800-00-X",
            "978-9947-999-99-X",
            "978-9948-00-000-X",
            "978-9948-39-999-X",
            "978-9948-400-00-X",
            "978-9948-849-99-X",
            "978-9948-8500-0-X",
            "978-9948-9999-9-X",
            "978-9949-0-0000-X",
            "978-9949-0-9999-X",
            "978-9949-10-000-X",
            "978-9949-39-999-X",
            "978-9949-400-00-X",
            "978-9949-899-99-X",
            "978-9949-9000-0-X",
            "978-9949-9999-9-X",
            "978-9950-00-000-X",
            "978-9950-29-999-X",
            "978-9950-300-00-X",
            "978-9950-849-99-X",
            "978-9950-8500-0-X",
            "978-9950-9999-9-X",
            "978-9951-00-000-X",
            "978-9951-39-999-X",
            "978-9951-400-00-X",
            "978-9951-849-99-X",
            "978-9951-8500-0-X",
            "978-9951-9999-9-X",
            "978-9952-0-0000-X",
            "978-9952-1-9999-X",
            "978-9952-20-000-X",
            "978-9952-39-999-X",
            "978-9952-400-00-X",
            "978-9952-799-99-X",
            "978-9952-8000-0-X",
            "978-9952-9999-9-X",
            "978-9953-0-0000-X",
            "978-9953-0-9999-X",
            "978-9953-10-000-X",
            "978-9953-39-999-X",
            "978-9953-400-00-X",
            "978-9953-599-99-X",
            "978-9953-60-000-X",
            "978-9953-89-999-X",
            "978-9953-9000-0-X",
            "978-9953-9999-9-X",
            "978-9954-0-0000-X",
            "978-9954-1-9999-X",
            "978-9954-20-000-X",
            "978-9954-39-999-X",
            "978-9954-400-00-X",
            "978-9954-799-99-X",
            "978-9954-8000-0-X",
            "978-9954-9999-9-X",
            "978-9955-00-000-X",
            "978-9955-39-999-X",
            "978-9955-400-00-X",
            "978-9955-929-99-X",
            "978-9955-9300-0-X",
            "978-9955-9999-9-X",
            "978-9956-0-0000-X",
            "978-9956-0-9999-X",
            "978-9956-10-000-X",
            "978-9956-39-999-X",
            "978-9956-400-00-X",
            "978-9956-899-99-X",
            "978-9956-9000-0-X",
            "978-9956-9999-9-X",
            "978-9957-00-000-X",
            "978-9957-39-999-X",
            "978-9957-400-00-X",
            "978-9957-699-99-X",
            "978-9957-70-000-X",
            "978-9957-84-999-X",
            "978-9957-8500-0-X",
            "978-9957-8799-9-X",
            "978-9957-88-000-X",
            "978-9957-99-999-X",
            "978-9958-00-000-X",
            "978-9958-03-999-X",
            "978-9958-040-00-X",
            "978-9958-089-99-X",
            "978-9958-0900-0-X",
            "978-9958-0999-9-X",
            "978-9958-10-000-X",
            "978-9958-18-999-X",
            "978-9958-1900-0-X",
            "978-9958-1999-9-X",
            "978-9958-20-000-X",
            "978-9958-49-999-X",
            "978-9958-500-00-X",
            "978-9958-899-99-X",
            "978-9958-9000-0-X",
            "978-9958-9999-9-X",
            "978-9959-0-0000-X",
            "978-9959-1-9999-X",
            "978-9959-20-000-X",
            "978-9959-79-999-X",
            "978-9959-800-00-X",
            "978-9959-949-99-X",
            "978-9959-9500-0-X",
            "978-9959-9699-9-X",
            "978-9959-970-00-X",
            "978-9959-979-99-X",
            "978-9959-98-000-X",
            "978-9959-99-999-X",
            "978-9960-00-000-X",
            "978-9960-59-999-X",
            "978-9960-600-00-X",
            "978-9960-899-99-X",
            "978-9960-9000-0-X",
            "978-9960-9999-9-X",
            "978-9961-0-0000-X",
            "978-9961-2-9999-X",
            "978-9961-30-000-X",
            "978-9961-69-999-X",
            "978-9961-700-00-X",
            "978-9961-949-99-X",
            "978-9961-9500-0-X",
            "978-9961-9999-9-X",
            "978-9962-00-000-X",
            "978-9962-54-999-X",
            "978-9962-5500-0-X",
            "978-9962-5599-9-X",
            "978-9962-56-000-X",
            "978-9962-59-999-X",
            "978-9962-600-00-X",
            "978-9962-849-99-X",
            "978-9962-8500-0-X",
            "978-9962-9999-9-X",
            "978-9963-0-0000-X",
            "978-9963-1-9999-X",
            "978-9963-20-000-X",
            "978-9963-24-999-X",
            "978-9963-250-00-X",
            "978-9963-279-99-X",
            "978-9963-2800-0-X",
            "978-9963-2999-9-X",
            "978-9963-30-000-X",
            "978-9963-54-999-X",
            "978-9963-550-00-X",
            "978-9963-734-99-X",
            "978-9963-7350-0-X",
            "978-9963-7499-9-X",
            "978-9963-7500-0-X",
            "978-9963-9999-9-X",
            "978-9964-0-0000-X",
            "978-9964-6-9999-X",
            "978-9964-70-000-X",
            "978-9964-94-999-X",
            "978-9964-950-00-X",
            "978-9964-999-99-X",
            "978-9965-00-000-X",
            "978-9965-39-999-X",
            "978-9965-400-00-X",
            "978-9965-899-99-X",
            "978-9965-9000-0-X",
            "978-9965-9999-9-X",
            "978-9966-000-00-X",
            "978-9966-149-99-X",
            "978-9966-1500-0-X",
            "978-9966-1999-9-X",
            "978-9966-20-000-X",
            "978-9966-69-999-X",
            "978-9966-7000-0-X",
            "978-9966-7499-9-X",
            "978-9966-750-00-X",
            "978-9966-959-99-X",
            "978-9966-9600-0-X",
            "978-9966-9999-9-X",
            "978-9967-00-000-X",
            "978-9967-39-999-X",
            "978-9967-400-00-X",
            "978-9967-899-99-X",
            "978-9967-9000-0-X",
            "978-9967-9999-9-X",
            "978-9968-00-000-X",
            "978-9968-49-999-X",
            "978-9968-500-00-X",
            "978-9968-939-99-X",
            "978-9968-9400-0-X",
            "978-9968-9999-9-X",
            "978-9970-00-000-X",
            "978-9970-39-999-X",
            "978-9970-400-00-X",
            "978-9970-899-99-X",
            "978-9970-9000-0-X",
            "978-9970-9999-9-X",
            "978-9971-0-0000-X",
            "978-9971-5-9999-X",
            "978-9971-60-000-X",
            "978-9971-89-999-X",
            "978-9971-900-00-X",
            "978-9971-989-99-X",
            "978-9971-9900-0-X",
            "978-9971-9999-9-X",
            "978-9972-00-000-X",
            "978-9972-09-999-X",
            "978-9972-1-0000-X",
            "978-9972-1-9999-X",
            "978-9972-200-00-X",
            "978-9972-249-99-X",
            "978-9972-2500-0-X",
            "978-9972-2999-9-X",
            "978-9972-30-000-X",
            "978-9972-59-999-X",
            "978-9972-600-00-X",
            "978-9972-899-99-X",
            "978-9972-9000-0-X",
            "978-9972-9999-9-X",
            "978-9973-00-000-X",
            "978-9973-05-999-X",
            "978-9973-060-00-X",
            "978-9973-089-99-X",
            "978-9973-0900-0-X",
            "978-9973-0999-9-X",
            "978-9973-10-000-X",
            "978-9973-69-999-X",
            "978-9973-700-00-X",
            "978-9973-969-99-X",
            "978-9973-9700-0-X",
            "978-9973-9999-9-X",
            "978-9974-0-0000-X",
            "978-9974-2-9999-X",
            "978-9974-30-000-X",
            "978-9974-54-999-X",
            "978-9974-550-00-X",
            "978-9974-749-99-X",
            "978-9974-7500-0-X",
            "978-9974-9499-9-X",
            "978-9974-95-000-X",
            "978-9974-99-999-X",
            "978-9975-0-0000-X",
            "978-9975-0-9999-X",
            "978-9975-100-00-X",
            "978-9975-399-99-X",
            "978-9975-4000-0-X",
            "978-9975-4499-9-X",
            "978-9975-45-000-X",
            "978-9975-89-999-X",
            "978-9975-900-00-X",
            "978-9975-949-99-X",
            "978-9975-9500-0-X",
            "978-9975-9999-9-X",
            "978-9976-0-0000-X",
            "978-9976-5-9999-X",
            "978-9976-60-000-X",
            "978-9976-89-999-X",
            "978-9976-900-00-X",
            "978-9976-989-99-X",
            "978-9976-9900-0-X",
            "978-9976-9999-9-X",
            "978-9977-00-000-X",
            "978-9977-89-999-X",
            "978-9977-900-00-X",
            "978-9977-989-99-X",
            "978-9977-9900-0-X",
            "978-9977-9999-9-X",
            "978-9978-00-000-X",
            "978-9978-29-999-X",
            "978-9978-300-00-X",
            "978-9978-399-99-X",
            "978-9978-40-000-X",
            "978-9978-94-999-X",
            "978-9978-950-00-X",
            "978-9978-989-99-X",
            "978-9978-9900-0-X",
            "978-9978-9999-9-X",
            "978-9979-0-0000-X",
            "978-9979-4-9999-X",
            "978-9979-50-000-X",
            "978-9979-64-999-X",
            "978-9979-650-00-X",
            "978-9979-659-99-X",
            "978-9979-66-000-X",
            "978-9979-75-999-X",
            "978-9979-760-00-X",
            "978-9979-899-99-X",
            "978-9979-9000-0-X",
            "978-9979-9999-9-X",
            "978-9980-0-0000-X",
            "978-9980-3-9999-X",
            "978-9980-40-000-X",
            "978-9980-89-999-X",
            "978-9980-900-00-X",
            "978-9980-989-99-X",
            "978-9980-9900-0-X",
            "978-9980-9999-9-X",
            "978-9981-00-000-X",
            "978-9981-09-999-X",
            "978-9981-100-00-X",
            "978-9981-159-99-X",
            "978-9981-1600-0-X",
            "978-9981-1999-9-X",
            "978-9981-20-000-X",
            "978-9981-79-999-X",
            "978-9981-800-00-X",
            "978-9981-949-99-X",
            "978-9981-9500-0-X",
            "978-9981-9999-9-X",
            "978-9982-00-000-X",
            "978-9982-79-999-X",
            "978-9982-800-00-X",
            "978-9982-989-99-X",
            "978-9982-9900-0-X",
            "978-9982-9999-9-X",
            "978-9983-80-000-X",
            "978-9983-94-999-X",
            "978-9983-950-00-X",
            "978-9983-989-99-X",
            "978-9983-9900-0-X",
            "978-9983-9999-9-X",
            "978-9984-00-000-X",
            "978-9984-49-999-X",
            "978-9984-500-00-X",
            "978-9984-899-99-X",
            "978-9984-9000-0-X",
            "978-9984-9999-9-X",
            "978-9985-0-0000-X",
            "978-9985-4-9999-X",
            "978-9985-50-000-X",
            "978-9985-79-999-X",
            "978-9985-800-00-X",
            "978-9985-899-99-X",
            "978-9985-9000-0-X",
            "978-9985-9999-9-X",
            "978-9986-00-000-X",
            "978-9986-39-999-X",
            "978-9986-400-00-X",
            "978-9986-899-99-X",
            "978-9986-9000-0-X",
            "978-9986-9399-9-X",
            "978-9986-940-00-X",
            "978-9986-969-99-X",
            "978-9986-97-000-X",
            "978-9986-99-999-X",
            "978-9987-00-000-X",
            "978-9987-39-999-X",
            "978-9987-400-00-X",
            "978-9987-879-99-X",
            "978-9987-8800-0-X",
            "978-9987-9999-9-X",
            "978-9988-0-0000-X",
            "978-9988-2-9999-X",
            "978-9988-30-000-X",
            "978-9988-54-999-X",
            "978-9988-550-00-X",
            "978-9988-749-99-X",
            "978-9988-7500-0-X",
            "978-9988-9999-9-X",
            "978-9989-0-0000-X",
            "978-9989-0-9999-X",
            "978-9989-100-00-X",
            "978-9989-199-99-X",
            "978-9989-2000-0-X",
            "978-9989-2999-9-X",
            "978-9989-30-000-X",
            "978-9989-59-999-X",
            "978-9989-600-00-X",
            "978-9989-949-99-X",
            "978-9989-9500-0-X",
            "978-9989-9999-9-X",
            "978-99901-00-00-X",
            "978-99901-49-99-X",
            "978-99901-500-0-X",
            "978-99901-799-9-X",
            "978-99901-80-00-X",
            "978-99901-99-99-X",
            "978-99903-0-000-X",
            "978-99903-1-999-X",
            "978-99903-20-00-X",
            "978-99903-89-99-X",
            "978-99903-900-0-X",
            "978-99903-999-9-X",
            "978-99904-0-000-X",
            "978-99904-5-999-X",
            "978-99904-60-00-X",
            "978-99904-89-99-X",
            "978-99904-900-0-X",
            "978-99904-999-9-X",
            "978-99905-0-000-X",
            "978-99905-3-999-X",
            "978-99905-40-00-X",
            "978-99905-79-99-X",
            "978-99905-800-0-X",
            "978-99905-999-9-X",
            "978-99906-0-000-X",
            "978-99906-2-999-X",
            "978-99906-30-00-X",
            "978-99906-59-99-X",
            "978-99906-600-0-X",
            "978-99906-699-9-X",
            "978-99906-70-00-X",
            "978-99906-89-99-X",
            "978-99906-90-00-X",
            "978-99906-94-99-X",
            "978-99906-950-0-X",
            "978-99906-999-9-X",
            "978-99908-0-000-X",
            "978-99908-0-999-X",
            "978-99908-10-00-X",
            "978-99908-89-99-X",
            "978-99908-900-0-X",
            "978-99908-999-9-X",
            "978-99909-0-000-X",
            "978-99909-3-999-X",
            "978-99909-40-00-X",
            "978-99909-94-99-X",
            "978-99909-950-0-X",
            "978-99909-999-9-X",
            "978-99910-0-000-X",
            "978-99910-2-999-X",
            "978-99910-30-00-X",
            "978-99910-89-99-X",
            "978-99910-900-0-X",
            "978-99910-999-9-X",
            "978-99911-00-00-X",
            "978-99911-59-99-X",
            "978-99911-600-0-X",
            "978-99911-999-9-X",
            "978-99912-0-000-X",
            "978-99912-3-999-X",
            "978-99912-400-0-X",
            "978-99912-599-9-X",
            "978-99912-60-00-X",
            "978-99912-89-99-X",
            "978-99912-900-0-X",
            "978-99912-999-9-X",
            "978-99913-0-000-X",
            "978-99913-2-999-X",
            "978-99913-30-00-X",
            "978-99913-35-99-X",
            "978-99913-600-0-X",
            "978-99913-604-9-X",
            "978-99914-0-000-X",
            "978-99914-4-999-X",
            "978-99914-50-00-X",
            "978-99914-89-99-X",
            "978-99914-900-0-X",
            "978-99914-999-9-X",
            "978-99915-0-000-X",
            "978-99915-4-999-X",
            "978-99915-50-00-X",
            "978-99915-79-99-X",
            "978-99915-800-0-X",
            "978-99915-999-9-X",
            "978-99916-0-000-X",
            "978-99916-2-999-X",
            "978-99916-30-00-X",
            "978-99916-69-99-X",
            "978-99916-700-0-X",
            "978-99916-999-9-X",
            "978-99917-0-000-X",
            "978-99917-2-999-X",
            "978-99917-30-00-X",
            "978-99917-89-99-X",
            "978-99917-900-0-X",
            "978-99917-999-9-X",
            "978-99918-0-000-X",
            "978-99918-3-999-X",
            "978-99918-40-00-X",
            "978-99918-79-99-X",
            "978-99918-800-0-X",
            "978-99918-999-9-X",
            "978-99919-0-000-X",
            "978-99919-2-999-X",
            "978-99919-300-0-X",
            "978-99919-399-9-X",
            "978-99919-40-00-X",
            "978-99919-69-99-X",
            "978-99919-70-00-X",
            "978-99919-79-99-X",
            "978-99919-800-0-X",
            "978-99919-849-9-X",
            "978-99919-850-0-X",
            "978-99919-899-9-X",
            "978-99919-900-0-X",
            "978-99919-999-9-X",
            "978-99920-0-000-X",
            "978-99920-4-999-X",
            "978-99920-50-00-X",
            "978-99920-89-99-X",
            "978-99920-900-0-X",
            "978-99920-999-9-X",
            "978-99921-0-000-X",
            "978-99921-1-999-X",
            "978-99921-20-00-X",
            "978-99921-69-99-X",
            "978-99921-700-0-X",
            "978-99921-799-9-X",
            "978-99921-8-000-X",
            "978-99921-8-999-X",
            "978-99921-90-00-X",
            "978-99921-99-99-X",
            "978-99922-0-000-X",
            "978-99922-3-999-X",
            "978-99922-40-00-X",
            "978-99922-69-99-X",
            "978-99922-700-0-X",
            "978-99922-999-9-X",
            "978-99923-0-000-X",
            "978-99923-1-999-X",
            "978-99923-20-00-X",
            "978-99923-79-99-X",
            "978-99923-800-0-X",
            "978-99923-999-9-X",
            "978-99924-0-000-X",
            "978-99924-1-999-X",
            "978-99924-20-00-X",
            "978-99924-79-99-X",
            "978-99924-800-0-X",
            "978-99924-999-9-X",
            "978-99925-0-000-X",
            "978-99925-3-999-X",
            "978-99925-40-00-X",
            "978-99925-79-99-X",
            "978-99925-800-0-X",
            "978-99925-999-9-X",
            "978-99926-0-000-X",
            "978-99926-0-999-X",
            "978-99926-10-00-X",
            "978-99926-59-99-X",
            "978-99926-600-0-X",
            "978-99926-899-9-X",
            "978-99926-90-00-X",
            "978-99926-99-99-X",
            "978-99927-0-000-X",
            "978-99927-2-999-X",
            "978-99927-30-00-X",
            "978-99927-59-99-X",
            "978-99927-600-0-X",
            "978-99927-999-9-X",
            "978-99928-0-000-X",
            "978-99928-0-999-X",
            "978-99928-10-00-X",
            "978-99928-79-99-X",
            "978-99928-800-0-X",
            "978-99928-999-9-X",
            "978-99929-0-000-X",
            "978-99929-4-999-X",
            "978-99929-50-00-X",
            "978-99929-79-99-X",
            "978-99929-800-0-X",
            "978-99929-999-9-X",
            "978-99930-0-000-X",
            "978-99930-4-999-X",
            "978-99930-50-00-X",
            "978-99930-79-99-X",
            "978-99930-800-0-X",
            "978-99930-999-9-X",
            "978-99931-0-000-X",
            "978-99931-4-999-X",
            "978-99931-50-00-X",
            "978-99931-79-99-X",
            "978-99931-800-0-X",
            "978-99931-999-9-X",
            "978-99932-0-000-X",
            "978-99932-0-999-X",
            "978-99932-10-00-X",
            "978-99932-59-99-X",
            "978-99932-600-0-X",
            "978-99932-699-9-X",
            "978-99932-7-000-X",
            "978-99932-7-999-X",
            "978-99932-80-00-X",
            "978-99932-99-99-X",
            "978-99933-0-000-X",
            "978-99933-2-999-X",
            "978-99933-30-00-X",
            "978-99933-59-99-X",
            "978-99933-600-0-X",
            "978-99933-999-9-X",
            "978-99934-0-000-X",
            "978-99934-1-999-X",
            "978-99934-20-00-X",
            "978-99934-79-99-X",
            "978-99934-800-0-X",
            "978-99934-999-9-X",
            "978-99935-0-000-X",
            "978-99935-2-999-X",
            "978-99935-30-00-X",
            "978-99935-59-99-X",
            "978-99935-600-0-X",
            "978-99935-699-9-X",
            "978-99935-7-000-X",
            "978-99935-8-999-X",
            "978-99935-90-00-X",
            "978-99935-99-99-X",
            "978-99936-0-000-X",
            "978-99936-0-999-X",
            "978-99936-10-00-X",
            "978-99936-59-99-X",
            "978-99936-600-0-X",
            "978-99936-999-9-X",
            "978-99937-0-000-X",
            "978-99937-1-999-X",
            "978-99937-20-00-X",
            "978-99937-59-99-X",
            "978-99937-600-0-X",
            "978-99937-999-9-X",
            "978-99938-0-000-X",
            "978-99938-1-999-X",
            "978-99938-20-00-X",
            "978-99938-59-99-X",
            "978-99938-600-0-X",
            "978-99938-899-9-X",
            "978-99938-90-00-X",
            "978-99938-99-99-X",
            "978-99939-0-000-X",
            "978-99939-5-999-X",
            "978-99939-60-00-X",
            "978-99939-89-99-X",
            "978-99939-900-0-X",
            "978-99939-999-9-X",
            "978-99940-0-000-X",
            "978-99940-0-999-X",
            "978-99940-10-00-X",
            "978-99940-69-99-X",
            "978-99940-700-0-X",
            "978-99940-999-9-X",
            "978-99941-0-000-X",
            "978-99941-2-999-X",
            "978-99941-30-00-X",
            "978-99941-79-99-X",
            "978-99941-800-0-X",
            "978-99941-999-9-X",
            "978-99942-0-000-X",
            "978-99942-4-999-X",
            "978-99942-50-00-X",
            "978-99942-79-99-X",
            "978-99942-800-0-X",
            "978-99942-999-9-X",
            "978-99943-0-000-X",
            "978-99943-2-999-X",
            "978-99943-30-00-X",
            "978-99943-59-99-X",
            "978-99943-600-0-X",
            "978-99943-999-9-X",
            "978-99944-0-000-X",
            "978-99944-4-999-X",
            "978-99944-50-00-X",
            "978-99944-79-99-X",
            "978-99944-800-0-X",
            "978-99944-999-9-X",
            "978-99945-0-000-X",
            "978-99945-5-999-X",
            "978-99945-60-00-X",
            "978-99945-89-99-X",
            "978-99945-900-0-X",
            "978-99945-999-9-X",
            "978-99946-0-000-X",
            "978-99946-2-999-X",
            "978-99946-30-00-X",
            "978-99946-59-99-X",
            "978-99946-600-0-X",
            "978-99946-999-9-X",
            "978-99947-0-000-X",
            "978-99947-2-999-X",
            "978-99947-30-00-X",
            "978-99947-69-99-X",
            "978-99947-700-0-X",
            "978-99947-959-9-X",
            "978-99947-96-00-X",
            "978-99947-99-99-X",
            "978-99948-0-000-X",
            "978-99948-4-999-X",
            "978-99948-50-00-X",
            "978-99948-79-99-X",
            "978-99948-800-0-X",
            "978-99948-999-9-X",
            "978-99949-0-000-X",
            "978-99949-1-999-X",
            "978-99949-20-00-X",
            "978-99949-89-99-X",
            "978-99949-900-0-X",
            "978-99949-999-9-X",
            "978-99950-0-000-X",
            "978-99950-4-999-X",
            "978-99950-50-00-X",
            "978-99950-79-99-X",
            "978-99950-800-0-X",
            "978-99950-999-9-X",
            "978-99952-0-000-X",
            "978-99952-4-999-X",
            "978-99952-50-00-X",
            "978-99952-79-99-X",
            "978-99952-800-0-X",
            "978-99952-999-9-X",
            "978-99953-0-000-X",
            "978-99953-2-999-X",
            "978-99953-30-00-X",
            "978-99953-79-99-X",
            "978-99953-800-0-X",
            "978-99953-939-9-X",
            "978-99953-94-00-X",
            "978-99953-99-99-X",
            "978-99954-0-000-X",
            "978-99954-2-999-X",
            "978-99954-30-00-X",
            "978-99954-69-99-X",
            "978-99954-700-0-X",
            "978-99954-879-9-X",
            "978-99954-88-00-X",
            "978-99954-99-99-X",
            "978-99955-0-000-X",
            "978-99955-0-999-X",
            "978-99955-10-00-X",
            "978-99955-19-99-X",
            "978-99955-20-00-X",
            "978-99955-59-99-X",
            "978-99955-600-0-X",
            "978-99955-799-9-X",
            "978-99955-80-00-X",
            "978-99955-89-99-X",
            "978-99955-90-00-X",
            "978-99955-99-99-X",
            "978-99956-00-00-X",
            "978-99956-59-99-X",
            "978-99956-600-0-X",
            "978-99956-859-9-X",
            "978-99956-86-00-X",
            "978-99956-99-99-X",
            "978-99957-0-000-X",
            "978-99957-1-999-X",
            "978-99957-20-00-X",
            "978-99957-79-99-X",
            "978-99957-800-0-X",
            "978-99957-999-9-X",
            "978-99958-0-000-X",
            "978-99958-4-999-X",
            "978-99958-50-00-X",
            "978-99958-94-99-X",
            "978-99958-950-0-X",
            "978-99958-999-9-X",
            "978-99959-0-000-X",
            "978-99959-2-999-X",
            "978-99959-30-00-X",
            "978-99959-59-99-X",
            "978-99959-600-0-X",
            "978-99959-999-9-X",
            "978-99960-0-000-X",
            "978-99960-0-999-X",
            "978-99960-10-00-X",
            "978-99960-94-99-X",
            "978-99960-950-0-X",
            "978-99960-999-9-X",
            "978-99961-0-000-X",
            "978-99961-3-999-X",
            "978-99961-40-00-X",
            "978-99961-89-99-X",
            "978-99961-900-0-X",
            "978-99961-999-9-X",
            "978-99962-0-000-X",
            "978-99962-4-999-X",
            "978-99962-50-00-X",
            "978-99962-79-99-X",
            "978-99962-800-0-X",
            "978-99962-999-9-X",
            "978-99963-00-00-X",
            "978-99963-49-99-X",
            "978-99963-500-0-X",
            "978-99963-999-9-X",
            "978-99964-0-000-X",
            "978-99964-1-999-X",
            "978-99964-20-00-X",
            "978-99964-79-99-X",
            "978-99964-800-0-X",
            "978-99964-999-9-X",
            "978-99965-0-000-X",
            "978-99965-3-999-X",
            "978-99965-40-00-X",
            "978-99965-79-99-X",
            "978-99965-800-0-X",
            "978-99965-999-9-X",
            "978-99966-0-000-X",
            "978-99966-2-999-X",
            "978-99966-30-00-X",
            "978-99966-69-99-X",
            "978-99966-700-0-X",
            "978-99966-799-9-X",
            "978-99967-0-000-X",
            "978-99967-1-999-X",
            "978-99967-20-00-X",
            "978-99967-59-99-X",
            "978-99967-600-0-X",
            "978-99967-899-9-X",
            "978-99968-0-000-X",
            "978-99968-3-999-X",
            "978-99968-400-0-X",
            "978-99968-599-9-X",
            "978-99968-60-00-X",
            "978-99968-89-99-X",
            "978-99968-900-0-X",
            "978-99968-999-9-X",
            "978-99969-0-000-X",
            "978-99969-4-999-X",
            "978-99969-50-00-X",
            "978-99969-79-99-X",
            "978-99969-800-0-X",
            "978-99969-999-9-X",
            "978-99970-0-000-X",
            "978-99970-4-999-X",
            "978-99970-50-00-X",
            "978-99970-89-99-X",
            "978-99970-900-0-X",
            "978-99970-999-9-X",
            "978-99971-0-000-X",
            "978-99971-5-999-X",
            "978-99971-60-00-X",
            "978-99971-84-99-X",
            "978-99971-850-0-X",
            "978-99971-999-9-X",
            "978-99972-0-000-X",
            "978-99972-4-999-X",
            "978-99972-50-00-X",
            "978-99972-89-99-X",
            "978-99972-900-0-X",
            "978-99972-999-9-X",
            "978-99973-0-000-X",
            "978-99973-3-999-X",
            "978-99973-40-00-X",
            "978-99973-79-99-X",
            "978-99973-800-0-X",
            "978-99973-999-9-X",
            "979-10-00-00000-X",
            "979-10-19-99999-X",
            "979-10-200-0000-X",
            "979-10-699-9999-X",
            "979-10-7000-000-X",
            "979-10-8999-999-X",
            "979-10-90000-00-X",
            "979-10-97599-99-X",
            "979-10-976000-0-X",
            "979-10-999999-9-X",
            "979-11-00-00000-X",
            "979-11-24-99999-X",
            "979-11-250-0000-X",
            "979-11-549-9999-X",
            "979-11-5500-000-X",
            "979-11-8499-999-X",
            "979-11-85000-00-X",
            "979-11-94999-99-X",
            "979-11-950000-0-X",
            "979-11-999999-9-X",};

        //Array of well-hyphenated ISBN-13
        //The checksum number is not well calculed
        this.ISBN10s = new String[]{
            "0-00-000000-X",
            "0-19-999999-X",
            "0-200-00000-X",
            "0-699-99999-X",
            "0-7000-0000-X",
            "0-8499-9999-X",
            "0-85000-000-X",
            "0-89999-999-X",
            "0-900000-00-X",
            "0-949999-99-X",
            "0-9500000-0-X",
            "0-9999999-9-X",
            "1-00-000000-X",
            "1-09-999999-X",
            "1-100-00000-X",
            "1-399-99999-X",
            "1-4000-0000-X",
            "1-5499-9999-X",
            "1-55000-000-X",
            "1-86979-999-X",
            "1-869800-00-X",
            "1-998999-99-X",
            "1-9990000-0-X",
            "1-9999999-9-X",
            "2-00-000000-X",
            "2-19-999999-X",
            "2-200-00000-X",
            "2-349-99999-X",
            "2-35000-000-X",
            "2-39999-999-X",
            "2-400-00000-X",
            "2-699-99999-X",
            "2-7000-0000-X",
            "2-8399-9999-X",
            "2-84000-000-X",
            "2-89999-999-X",
            "2-900000-00-X",
            "2-949999-99-X",
            "2-9500000-0-X",
            "2-9999999-9-X",
            "3-00-000000-X",
            "3-02-999999-X",
            "3-030-00000-X",
            "3-033-99999-X",
            "3-0340-0000-X",
            "3-0369-9999-X",
            "3-03700-000-X",
            "3-03999-999-X",
            "3-04-000000-X",
            "3-19-999999-X",
            "3-200-00000-X",
            "3-699-99999-X",
            "3-7000-0000-X",
            "3-8499-9999-X",
            "3-85000-000-X",
            "3-89999-999-X",
            "3-900000-00-X",
            "3-949999-99-X",
            "3-9500000-0-X",
            "3-9539999-9-X",
            "3-95400-000-X",
            "3-96999-999-X",
            "3-9700000-0-X",
            "3-9899999-9-X",
            "3-99000-000-X",
            "3-99499-999-X",
            "3-99500-000-X",
            "3-99999-999-X",
            "4-00-000000-X",
            "4-19-999999-X",
            "4-200-00000-X",
            "4-699-99999-X",
            "4-7000-0000-X",
            "4-8499-9999-X",
            "4-85000-000-X",
            "4-89999-999-X",
            "4-900000-00-X",
            "4-949999-99-X",
            "4-9500000-0-X",
            "4-9999999-9-X",
            "5-00000-000-X",
            "5-00499-999-X",
            "5-0050-0000-X",
            "5-0099-9999-X",
            "5-01-000000-X",
            "5-19-999999-X",
            "5-200-00000-X",
            "5-420-99999-X",
            "5-4210-0000-X",
            "5-4299-9999-X",
            "5-430-00000-X",
            "5-430-99999-X",
            "5-4310-0000-X",
            "5-4399-9999-X",
            "5-440-00000-X",
            "5-440-99999-X",
            "5-4410-0000-X",
            "5-4499-9999-X",
            "5-450-00000-X",
            "5-699-99999-X",
            "5-7000-0000-X",
            "5-8499-9999-X",
            "5-85000-000-X",
            "5-89999-999-X",
            "5-900000-00-X",
            "5-909999-99-X",
            "5-91000-000-X",
            "5-91999-999-X",
            "5-9200-0000-X",
            "5-9299-9999-X",
            "5-93000-000-X",
            "5-94999-999-X",
            "5-9500000-0-X",
            "5-9500999-9-X",
            "5-9501-0000-X",
            "5-9799-9999-X",
            "5-98000-000-X",
            "5-98999-999-X",
            "5-9900000-0-X",
            "5-9909999-9-X",
            "5-9910-0000-X",
            "5-9999-9999-X",
            "600-00-0000-X",
            "600-09-9999-X",
            "600-100-000-X",
            "600-499-999-X",
            "600-5000-00-X",
            "600-8999-99-X",
            "600-90000-0-X",
            "600-99999-9-X",
            "601-00-0000-X",
            "601-19-9999-X",
            "601-200-000-X",
            "601-699-999-X",
            "601-7000-00-X",
            "601-7999-99-X",
            "601-80000-0-X",
            "601-84999-9-X",
            "601-85-0000-X",
            "601-99-9999-X",
            "602-00-0000-X",
            "602-13-9999-X",
            "602-14000-0-X",
            "602-14999-9-X",
            "602-1500-00-X",
            "602-1699-99-X",
            "602-17000-0-X",
            "602-17999-9-X",
            "602-18000-0-X",
            "602-18999-9-X",
            "602-19000-0-X",
            "602-19999-9-X",
            "602-200-000-X",
            "602-749-999-X",
            "602-7500-00-X",
            "602-7999-99-X",
            "602-8000-00-X",
            "602-9499-99-X",
            "602-95000-0-X",
            "602-99999-9-X",
            "603-00-0000-X",
            "603-04-9999-X",
            "603-05-0000-X",
            "603-49-9999-X",
            "603-500-000-X",
            "603-799-999-X",
            "603-8000-00-X",
            "603-8999-99-X",
            "603-90000-0-X",
            "603-99999-9-X",
            "604-0-00000-X",
            "604-4-99999-X",
            "604-50-0000-X",
            "604-89-9999-X",
            "604-900-000-X",
            "604-979-999-X",
            "604-9800-00-X",
            "604-9999-99-X",
            "605-01-0000-X",
            "605-09-9999-X",
            "605-100-000-X",
            "605-399-999-X",
            "605-4000-00-X",
            "605-5999-99-X",
            "605-60000-0-X",
            "605-89999-9-X",
            "605-90-0000-X",
            "605-99-9999-X",
            "606-0-00000-X",
            "606-0-99999-X",
            "606-10-0000-X",
            "606-49-9999-X",
            "606-500-000-X",
            "606-799-999-X",
            "606-8000-00-X",
            "606-9199-99-X",
            "606-92000-0-X",
            "606-99999-9-X",
            "607-00-0000-X",
            "607-39-9999-X",
            "607-400-000-X",
            "607-749-999-X",
            "607-7500-00-X",
            "607-9499-99-X",
            "607-95000-0-X",
            "607-99999-9-X",
            "608-0-00000-X",
            "608-0-99999-X",
            "608-10-0000-X",
            "608-19-9999-X",
            "608-200-000-X",
            "608-449-999-X",
            "608-4500-00-X",
            "608-6499-99-X",
            "608-65000-0-X",
            "608-69999-9-X",
            "608-7-00000-X",
            "608-9-99999-X",
            "609-00-0000-X",
            "609-39-9999-X",
            "609-400-000-X",
            "609-799-999-X",
            "609-8000-00-X",
            "609-9499-99-X",
            "609-95000-0-X",
            "609-99999-9-X",
            "612-00-0000-X",
            "612-29-9999-X",
            "612-300-000-X",
            "612-399-999-X",
            "612-4000-00-X",
            "612-4499-99-X",
            "612-45000-0-X",
            "612-49999-9-X",
            "612-50-0000-X",
            "612-99-9999-X",
            "613-0-00000-X",
            "613-9-99999-X",
            "614-00-0000-X",
            "614-39-9999-X",
            "614-400-000-X",
            "614-799-999-X",
            "614-8000-00-X",
            "614-9499-99-X",
            "614-95000-0-X",
            "614-99999-9-X",
            "615-00-0000-X",
            "615-09-9999-X",
            "615-100-000-X",
            "615-499-999-X",
            "615-5000-00-X",
            "615-7999-99-X",
            "615-80000-0-X",
            "615-89999-9-X",
            "616-00-0000-X",
            "616-19-9999-X",
            "616-200-000-X",
            "616-699-999-X",
            "616-7000-00-X",
            "616-8999-99-X",
            "616-90000-0-X",
            "616-99999-9-X",
            "617-00-0000-X",
            "617-49-9999-X",
            "617-500-000-X",
            "617-699-999-X",
            "617-7000-00-X",
            "617-8999-99-X",
            "617-90000-0-X",
            "617-99999-9-X",
            "618-00-0000-X",
            "618-19-9999-X",
            "618-200-000-X",
            "618-499-999-X",
            "618-5000-00-X",
            "618-7999-99-X",
            "618-80000-0-X",
            "618-99999-9-X",
            "619-00-0000-X",
            "619-14-9999-X",
            "619-150-000-X",
            "619-699-999-X",
            "619-7000-00-X",
            "619-8999-99-X",
            "619-90000-0-X",
            "619-99999-9-X",
            "620-0-00000-X",
            "620-9-99999-X",
            "621-00-0000-X",
            "621-29-9999-X",
            "621-400-000-X",
            "621-599-999-X",
            "621-8000-00-X",
            "621-8999-99-X",
            "621-95000-0-X",
            "621-99999-9-X",
            "7-00-000000-X",
            "7-09-999999-X",
            "7-100-00000-X",
            "7-499-99999-X",
            "7-5000-0000-X",
            "7-7999-9999-X",
            "7-80000-000-X",
            "7-89999-999-X",
            "7-900000-00-X",
            "7-999999-99-X",
            "80-00-00000-X",
            "80-19-99999-X",
            "80-200-0000-X",
            "80-699-9999-X",
            "80-7000-000-X",
            "80-8499-999-X",
            "80-85000-00-X",
            "80-89999-99-X",
            "80-900000-0-X",
            "80-999999-9-X",
            "81-00-00000-X",
            "81-19-99999-X",
            "81-200-0000-X",
            "81-699-9999-X",
            "81-7000-000-X",
            "81-8499-999-X",
            "81-85000-00-X",
            "81-89999-99-X",
            "81-900000-0-X",
            "81-999999-9-X",
            "82-00-00000-X",
            "82-19-99999-X",
            "82-200-0000-X",
            "82-699-9999-X",
            "82-7000-000-X",
            "82-8999-999-X",
            "82-90000-00-X",
            "82-98999-99-X",
            "82-990000-0-X",
            "82-999999-9-X",
            "83-00-00000-X",
            "83-19-99999-X",
            "83-200-0000-X",
            "83-599-9999-X",
            "83-60000-00-X",
            "83-69999-99-X",
            "83-7000-000-X",
            "83-8499-999-X",
            "83-85000-00-X",
            "83-89999-99-X",
            "83-900000-0-X",
            "83-999999-9-X",
            "84-00-00000-X",
            "84-13-99999-X",
            "84-140-0000-X",
            "84-149-9999-X",
            "84-15000-00-X",
            "84-19999-99-X",
            "84-200-0000-X",
            "84-699-9999-X",
            "84-7000-000-X",
            "84-8499-999-X",
            "84-85000-00-X",
            "84-89999-99-X",
            "84-9000-000-X",
            "84-9199-999-X",
            "84-920000-0-X",
            "84-923999-9-X",
            "84-92400-00-X",
            "84-92999-99-X",
            "84-930000-0-X",
            "84-949999-9-X",
            "84-95000-00-X",
            "84-96999-99-X",
            "84-9700-000-X",
            "84-9999-999-X",
            "85-00-00000-X",
            "85-19-99999-X",
            "85-200-0000-X",
            "85-599-9999-X",
            "85-60000-00-X",
            "85-69999-99-X",
            "85-7000-000-X",
            "85-8499-999-X",
            "85-85000-00-X",
            "85-89999-99-X",
            "85-900000-0-X",
            "85-979999-9-X",
            "85-98000-00-X",
            "85-99999-99-X",
            "86-00-00000-X",
            "86-29-99999-X",
            "86-300-0000-X",
            "86-599-9999-X",
            "86-6000-000-X",
            "86-7999-999-X",
            "86-80000-00-X",
            "86-89999-99-X",
            "86-900000-0-X",
            "86-999999-9-X",
            "87-00-00000-X",
            "87-29-99999-X",
            "87-400-0000-X",
            "87-649-9999-X",
            "87-7000-000-X",
            "87-7999-999-X",
            "87-85000-00-X",
            "87-94999-99-X",
            "87-970000-0-X",
            "87-999999-9-X",
            "88-00-00000-X",
            "88-19-99999-X",
            "88-200-0000-X",
            "88-599-9999-X",
            "88-6000-000-X",
            "88-8499-999-X",
            "88-85000-00-X",
            "88-89999-99-X",
            "88-900000-0-X",
            "88-909999-9-X",
            "88-910-0000-X",
            "88-929-9999-X",
            "88-9300-000-X",
            "88-9399-999-X",
            "88-940000-0-X",
            "88-949999-9-X",
            "88-95000-00-X",
            "88-99999-99-X",
            "89-00-00000-X",
            "89-24-99999-X",
            "89-250-0000-X",
            "89-549-9999-X",
            "89-5500-000-X",
            "89-8499-999-X",
            "89-85000-00-X",
            "89-94999-99-X",
            "89-950000-0-X",
            "89-969999-9-X",
            "89-97000-00-X",
            "89-98999-99-X",
            "89-990-0000-X",
            "89-999-9999-X",
            "90-00-00000-X",
            "90-19-99999-X",
            "90-200-0000-X",
            "90-499-9999-X",
            "90-5000-000-X",
            "90-6999-999-X",
            "90-70000-00-X",
            "90-79999-99-X",
            "90-800000-0-X",
            "90-849999-9-X",
            "90-8500-000-X",
            "90-8999-999-X",
            "90-90-00000-X",
            "90-90-99999-X",
            "90-94-00000-X",
            "90-94-99999-X",
            "91-0-000000-X",
            "91-1-999999-X",
            "91-20-00000-X",
            "91-49-99999-X",
            "91-500-0000-X",
            "91-649-9999-X",
            "91-7000-000-X",
            "91-7999-999-X",
            "91-85000-00-X",
            "91-94999-99-X",
            "91-970000-0-X",
            "91-999999-9-X",
            "92-0-000000-X",
            "92-5-999999-X",
            "92-60-00000-X",
            "92-79-99999-X",
            "92-800-0000-X",
            "92-899-9999-X",
            "92-9000-000-X",
            "92-9499-999-X",
            "92-95000-00-X",
            "92-98999-99-X",
            "92-990000-0-X",
            "92-999999-9-X",
            "93-00-00000-X",
            "93-09-99999-X",
            "93-100-0000-X",
            "93-499-9999-X",
            "93-5000-000-X",
            "93-7999-999-X",
            "93-80000-00-X",
            "93-94999-99-X",
            "93-950000-0-X",
            "93-999999-9-X",
            "94-000-0000-X",
            "94-599-9999-X",
            "94-6000-000-X",
            "94-8999-999-X",
            "94-90000-00-X",
            "94-99999-99-X",
            "950-00-0000-X",
            "950-49-9999-X",
            "950-500-000-X",
            "950-899-999-X",
            "950-9000-00-X",
            "950-9899-99-X",
            "950-99000-0-X",
            "950-99999-9-X",
            "951-0-00000-X",
            "951-1-99999-X",
            "951-20-0000-X",
            "951-54-9999-X",
            "951-550-000-X",
            "951-889-999-X",
            "951-8900-00-X",
            "951-9499-99-X",
            "951-95000-0-X",
            "951-99999-9-X",
            "952-00-0000-X",
            "952-19-9999-X",
            "952-200-000-X",
            "952-499-999-X",
            "952-5000-00-X",
            "952-5999-99-X",
            "952-60-0000-X",
            "952-65-9999-X",
            "952-6600-00-X",
            "952-6699-99-X",
            "952-67000-0-X",
            "952-69999-9-X",
            "952-7000-00-X",
            "952-7999-99-X",
            "952-80-0000-X",
            "952-94-9999-X",
            "952-9500-00-X",
            "952-9899-99-X",
            "952-99000-0-X",
            "952-99999-9-X",
            "953-0-00000-X",
            "953-0-99999-X",
            "953-10-0000-X",
            "953-14-9999-X",
            "953-150-000-X",
            "953-509-999-X",
            "953-51-0000-X",
            "953-54-9999-X",
            "953-55000-0-X",
            "953-59999-9-X",
            "953-6000-00-X",
            "953-9499-99-X",
            "953-95000-0-X",
            "953-99999-9-X",
            "954-00-0000-X",
            "954-28-9999-X",
            "954-2900-00-X",
            "954-2999-99-X",
            "954-300-000-X",
            "954-799-999-X",
            "954-8000-00-X",
            "954-8999-99-X",
            "954-90000-0-X",
            "954-92999-9-X",
            "954-9300-00-X",
            "954-9999-99-X",
            "955-0000-00-X",
            "955-1999-99-X",
            "955-20-0000-X",
            "955-43-9999-X",
            "955-44000-0-X",
            "955-44999-9-X",
            "955-4500-00-X",
            "955-4999-99-X",
            "955-50000-0-X",
            "955-54999-9-X",
            "955-550-000-X",
            "955-799-999-X",
            "955-8000-00-X",
            "955-9499-99-X",
            "955-95000-0-X",
            "955-99999-9-X",
            "956-00-0000-X",
            "956-19-9999-X",
            "956-200-000-X",
            "956-699-999-X",
            "956-7000-00-X",
            "956-9999-99-X",
            "957-00-0000-X",
            "957-02-9999-X",
            "957-0300-00-X",
            "957-0499-99-X",
            "957-05-0000-X",
            "957-19-9999-X",
            "957-2000-00-X",
            "957-2099-99-X",
            "957-21-0000-X",
            "957-27-9999-X",
            "957-28000-0-X",
            "957-30999-9-X",
            "957-31-0000-X",
            "957-43-9999-X",
            "957-440-000-X",
            "957-819-999-X",
            "957-8200-00-X",
            "957-9699-99-X",
            "957-97000-0-X",
            "957-99999-9-X",
            "958-00-0000-X",
            "958-56-9999-X",
            "958-57000-0-X",
            "958-59999-9-X",
            "958-600-000-X",
            "958-799-999-X",
            "958-8000-00-X",
            "958-9499-99-X",
            "958-95000-0-X",
            "958-99999-9-X",
            "959-00-0000-X",
            "959-19-9999-X",
            "959-200-000-X",
            "959-699-999-X",
            "959-7000-00-X",
            "959-8499-99-X",
            "959-85000-0-X",
            "959-99999-9-X",
            "960-00-0000-X",
            "960-19-9999-X",
            "960-200-000-X",
            "960-659-999-X",
            "960-6600-00-X",
            "960-6899-99-X",
            "960-690-000-X",
            "960-699-999-X",
            "960-7000-00-X",
            "960-8499-99-X",
            "960-85000-0-X",
            "960-92999-9-X",
            "960-93-0000-X",
            "960-93-9999-X",
            "960-9400-00-X",
            "960-9799-99-X",
            "960-98000-0-X",
            "960-99999-9-X",
            "961-00-0000-X",
            "961-19-9999-X",
            "961-200-000-X",
            "961-599-999-X",
            "961-6000-00-X",
            "961-8999-99-X",
            "961-90000-0-X",
            "961-94999-9-X",
            "962-00-0000-X",
            "962-19-9999-X",
            "962-200-000-X",
            "962-699-999-X",
            "962-7000-00-X",
            "962-8499-99-X",
            "962-85000-0-X",
            "962-86999-9-X",
            "962-8700-00-X",
            "962-8999-99-X",
            "962-900-000-X",
            "962-999-999-X",
            "963-00-0000-X",
            "963-19-9999-X",
            "963-200-000-X",
            "963-699-999-X",
            "963-7000-00-X",
            "963-8499-99-X",
            "963-85000-0-X",
            "963-89999-9-X",
            "963-9000-00-X",
            "963-9999-99-X",
            "964-00-0000-X",
            "964-14-9999-X",
            "964-150-000-X",
            "964-249-999-X",
            "964-2500-00-X",
            "964-2999-99-X",
            "964-300-000-X",
            "964-549-999-X",
            "964-5500-00-X",
            "964-8999-99-X",
            "964-90000-0-X",
            "964-96999-9-X",
            "964-970-000-X",
            "964-989-999-X",
            "964-9900-00-X",
            "964-9999-99-X",
            "965-00-0000-X",
            "965-19-9999-X",
            "965-200-000-X",
            "965-599-999-X",
            "965-7000-00-X",
            "965-7999-99-X",
            "965-90000-0-X",
            "965-99999-9-X",
            "966-00-0000-X",
            "966-12-9999-X",
            "966-130-000-X",
            "966-139-999-X",
            "966-14-0000-X",
            "966-14-9999-X",
            "966-1500-00-X",
            "966-1699-99-X",
            "966-170-000-X",
            "966-199-999-X",
            "966-2000-00-X",
            "966-2789-99-X",
            "966-279-000-X",
            "966-289-999-X",
            "966-2900-00-X",
            "966-2999-99-X",
            "966-300-000-X",
            "966-699-999-X",
            "966-7000-00-X",
            "966-8999-99-X",
            "966-90000-0-X",
            "966-90999-9-X",
            "966-910-000-X",
            "966-949-999-X",
            "966-95000-0-X",
            "966-97999-9-X",
            "966-980-000-X",
            "966-999-999-X",
            "967-00-0000-X",
            "967-00-9999-X",
            "967-0100-00-X",
            "967-0999-99-X",
            "967-10000-0-X",
            "967-19999-9-X",
            "967-300-000-X",
            "967-499-999-X",
            "967-5000-00-X",
            "967-5999-99-X",
            "967-60-0000-X",
            "967-89-9999-X",
            "967-900-000-X",
            "967-989-999-X",
            "967-9900-00-X",
            "967-9989-99-X",
            "967-99900-0-X",
            "967-99999-9-X",
            "968-01-0000-X",
            "968-39-9999-X",
            "968-400-000-X",
            "968-499-999-X",
            "968-5000-00-X",
            "968-7999-99-X",
            "968-800-000-X",
            "968-899-999-X",
            "968-9000-00-X",
            "968-9999-99-X",
            "969-0-00000-X",
            "969-1-99999-X",
            "969-20-0000-X",
            "969-39-9999-X",
            "969-400-000-X",
            "969-799-999-X",
            "969-8000-00-X",
            "969-9999-99-X",
            "970-01-0000-X",
            "970-59-9999-X",
            "970-600-000-X",
            "970-899-999-X",
            "970-9000-00-X",
            "970-9099-99-X",
            "970-91000-0-X",
            "970-96999-9-X",
            "970-9700-00-X",
            "970-9999-99-X",
            "971-000-000-X",
            "971-015-999-X",
            "971-0160-00-X",
            "971-0199-99-X",
            "971-02-0000-X",
            "971-02-9999-X",
            "971-0300-00-X",
            "971-0599-99-X",
            "971-06-0000-X",
            "971-49-9999-X",
            "971-500-000-X",
            "971-849-999-X",
            "971-8500-00-X",
            "971-9099-99-X",
            "971-91000-0-X",
            "971-95999-9-X",
            "971-9600-00-X",
            "971-9699-99-X",
            "971-97-0000-X",
            "971-98-9999-X",
            "971-9900-00-X",
            "971-9999-99-X",
            "972-0-00000-X",
            "972-1-99999-X",
            "972-20-0000-X",
            "972-54-9999-X",
            "972-550-000-X",
            "972-799-999-X",
            "972-8000-00-X",
            "972-9499-99-X",
            "972-95000-0-X",
            "972-99999-9-X",
            "973-0-00000-X",
            "973-0-99999-X",
            "973-100-000-X",
            "973-169-999-X",
            "973-1700-00-X",
            "973-1999-99-X",
            "973-20-0000-X",
            "973-54-9999-X",
            "973-550-000-X",
            "973-759-999-X",
            "973-7600-00-X",
            "973-8499-99-X",
            "973-85000-0-X",
            "973-88999-9-X",
            "973-8900-00-X",
            "973-9499-99-X",
            "973-95000-0-X",
            "973-99999-9-X",
            "974-00-0000-X",
            "974-19-9999-X",
            "974-200-000-X",
            "974-699-999-X",
            "974-7000-00-X",
            "974-8499-99-X",
            "974-85000-0-X",
            "974-89999-9-X",
            "974-90000-0-X",
            "974-94999-9-X",
            "974-9500-00-X",
            "974-9999-99-X",
            "975-00000-0-X",
            "975-01999-9-X",
            "975-02-0000-X",
            "975-24-9999-X",
            "975-250-000-X",
            "975-599-999-X",
            "975-6000-00-X",
            "975-9199-99-X",
            "975-92000-0-X",
            "975-98999-9-X",
            "975-990-000-X",
            "975-999-999-X",
            "976-0-00000-X",
            "976-3-99999-X",
            "976-40-0000-X",
            "976-59-9999-X",
            "976-600-000-X",
            "976-799-999-X",
            "976-8000-00-X",
            "976-9499-99-X",
            "976-95000-0-X",
            "976-99999-9-X",
            "977-00-0000-X",
            "977-19-9999-X",
            "977-200-000-X",
            "977-499-999-X",
            "977-5000-00-X",
            "977-6999-99-X",
            "977-700-000-X",
            "977-849-999-X",
            "977-85000-0-X",
            "977-89999-9-X",
            "977-90-0000-X",
            "977-99-9999-X",
            "978-000-000-X",
            "978-199-999-X",
            "978-2000-00-X",
            "978-2999-99-X",
            "978-30000-0-X",
            "978-79999-9-X",
            "978-8000-00-X",
            "978-8999-99-X",
            "978-900-000-X",
            "978-999-999-X",
            "979-000-000-X",
            "979-099-999-X",
            "979-1000-00-X",
            "979-1499-99-X",
            "979-15000-0-X",
            "979-19999-9-X",
            "979-20-0000-X",
            "979-29-9999-X",
            "979-3000-00-X",
            "979-3999-99-X",
            "979-400-000-X",
            "979-799-999-X",
            "979-8000-00-X",
            "979-9499-99-X",
            "979-95000-0-X",
            "979-99999-9-X",
            "980-00-0000-X",
            "980-19-9999-X",
            "980-200-000-X",
            "980-599-999-X",
            "980-6000-00-X",
            "980-9999-99-X",
            "981-00-0000-X",
            "981-11-9999-X",
            "981-200-000-X",
            "981-289-999-X",
            "981-290-000-X",
            "981-299-999-X",
            "981-3000-00-X",
            "981-3099-99-X",
            "981-310-000-X",
            "981-399-999-X",
            "981-4000-00-X",
            "981-9999-99-X",
            "982-00-0000-X",
            "982-09-9999-X",
            "982-100-000-X",
            "982-699-999-X",
            "982-70-0000-X",
            "982-89-9999-X",
            "982-9000-00-X",
            "982-9799-99-X",
            "982-98000-0-X",
            "982-99999-9-X",
            "983-00-0000-X",
            "983-01-9999-X",
            "983-020-000-X",
            "983-199-999-X",
            "983-2000-00-X",
            "983-3999-99-X",
            "983-40000-0-X",
            "983-44999-9-X",
            "983-45-0000-X",
            "983-49-9999-X",
            "983-50-0000-X",
            "983-79-9999-X",
            "983-800-000-X",
            "983-899-999-X",
            "983-9000-00-X",
            "983-9899-99-X",
            "983-99000-0-X",
            "983-99999-9-X",
            "984-00-0000-X",
            "984-39-9999-X",
            "984-400-000-X",
            "984-799-999-X",
            "984-8000-00-X",
            "984-8999-99-X",
            "984-90000-0-X",
            "984-99999-9-X",
            "985-00-0000-X",
            "985-39-9999-X",
            "985-400-000-X",
            "985-599-999-X",
            "985-6000-00-X",
            "985-8999-99-X",
            "985-90000-0-X",
            "985-99999-9-X",
            "986-00-0000-X",
            "986-11-9999-X",
            "986-120-000-X",
            "986-559-999-X",
            "986-5600-00-X",
            "986-7999-99-X",
            "986-80000-0-X",
            "986-99999-9-X",
            "987-00-0000-X",
            "987-09-9999-X",
            "987-1000-00-X",
            "987-1999-99-X",
            "987-20000-0-X",
            "987-29999-9-X",
            "987-30-0000-X",
            "987-35-9999-X",
            "987-3600-00-X",
            "987-3999-99-X",
            "987-40-0000-X",
            "987-44-9999-X",
            "987-45000-0-X",
            "987-49999-9-X",
            "987-500-000-X",
            "987-899-999-X",
            "987-9000-00-X",
            "987-9499-99-X",
            "987-95000-0-X",
            "987-99999-9-X",
            "988-00-0000-X",
            "988-11-9999-X",
            "988-12000-0-X",
            "988-14999-9-X",
            "988-15000-0-X",
            "988-16999-9-X",
            "988-17000-0-X",
            "988-19999-9-X",
            "988-200-000-X",
            "988-799-999-X",
            "988-8000-00-X",
            "988-9699-99-X",
            "988-97000-0-X",
            "988-99999-9-X",
            "989-0-00000-X",
            "989-1-99999-X",
            "989-20-0000-X",
            "989-54-9999-X",
            "989-550-000-X",
            "989-799-999-X",
            "989-8000-00-X",
            "989-9499-99-X",
            "989-95000-0-X",
            "989-99999-9-X",
            "9927-00-000-X",
            "9927-09-999-X",
            "9927-100-00-X",
            "9927-399-99-X",
            "9927-4000-0-X",
            "9927-4999-9-X",
            "9928-00-000-X",
            "9928-09-999-X",
            "9928-100-00-X",
            "9928-399-99-X",
            "9928-4000-0-X",
            "9928-4999-9-X",
            "9929-0-0000-X",
            "9929-3-9999-X",
            "9929-40-000-X",
            "9929-54-999-X",
            "9929-550-00-X",
            "9929-799-99-X",
            "9929-8000-0-X",
            "9929-9999-9-X",
            "9930-00-000-X",
            "9930-49-999-X",
            "9930-500-00-X",
            "9930-939-99-X",
            "9930-9400-0-X",
            "9930-9999-9-X",
            "9931-00-000-X",
            "9931-29-999-X",
            "9931-300-00-X",
            "9931-899-99-X",
            "9931-9000-0-X",
            "9931-9999-9-X",
            "9932-00-000-X",
            "9932-39-999-X",
            "9932-400-00-X",
            "9932-849-99-X",
            "9932-8500-0-X",
            "9932-9999-9-X",
            "9933-0-0000-X",
            "9933-0-9999-X",
            "9933-10-000-X",
            "9933-39-999-X",
            "9933-400-00-X",
            "9933-899-99-X",
            "9933-9000-0-X",
            "9933-9999-9-X",
            "9934-0-0000-X",
            "9934-0-9999-X",
            "9934-10-000-X",
            "9934-49-999-X",
            "9934-500-00-X",
            "9934-799-99-X",
            "9934-8000-0-X",
            "9934-9999-9-X",
            "9935-0-0000-X",
            "9935-0-9999-X",
            "9935-10-000-X",
            "9935-39-999-X",
            "9935-400-00-X",
            "9935-899-99-X",
            "9935-9000-0-X",
            "9935-9999-9-X",
            "9936-0-0000-X",
            "9936-1-9999-X",
            "9936-20-000-X",
            "9936-39-999-X",
            "9936-400-00-X",
            "9936-799-99-X",
            "9936-8000-0-X",
            "9936-9999-9-X",
            "9937-0-0000-X",
            "9937-2-9999-X",
            "9937-30-000-X",
            "9937-49-999-X",
            "9937-500-00-X",
            "9937-799-99-X",
            "9937-8000-0-X",
            "9937-9999-9-X",
            "9938-00-000-X",
            "9938-79-999-X",
            "9938-800-00-X",
            "9938-949-99-X",
            "9938-9500-0-X",
            "9938-9999-9-X",
            "9939-0-0000-X",
            "9939-4-9999-X",
            "9939-50-000-X",
            "9939-79-999-X",
            "9939-800-00-X",
            "9939-899-99-X",
            "9939-9000-0-X",
            "9939-9999-9-X",
            "9940-0-0000-X",
            "9940-1-9999-X",
            "9940-20-000-X",
            "9940-49-999-X",
            "9940-500-00-X",
            "9940-899-99-X",
            "9940-9000-0-X",
            "9940-9999-9-X",
            "9941-0-0000-X",
            "9941-0-9999-X",
            "9941-10-000-X",
            "9941-39-999-X",
            "9941-400-00-X",
            "9941-899-99-X",
            "9941-9000-0-X",
            "9941-9999-9-X",
            "9942-00-000-X",
            "9942-89-999-X",
            "9942-900-00-X",
            "9942-984-99-X",
            "9942-9850-0-X",
            "9942-9999-9-X",
            "9943-00-000-X",
            "9943-29-999-X",
            "9943-300-00-X",
            "9943-399-99-X",
            "9943-4000-0-X",
            "9943-9999-9-X",
            "9944-0000-0-X",
            "9944-0999-9-X",
            "9944-100-00-X",
            "9944-499-99-X",
            "9944-5000-0-X",
            "9944-5999-9-X",
            "9944-60-000-X",
            "9944-69-999-X",
            "9944-700-00-X",
            "9944-799-99-X",
            "9944-80-000-X",
            "9944-89-999-X",
            "9944-900-00-X",
            "9944-999-99-X",
            "9945-00-000-X",
            "9945-00-999-X",
            "9945-010-00-X",
            "9945-079-99-X",
            "9945-08-000-X",
            "9945-39-999-X",
            "9945-400-00-X",
            "9945-569-99-X",
            "9945-57-000-X",
            "9945-57-999-X",
            "9945-580-00-X",
            "9945-849-99-X",
            "9945-8500-0-X",
            "9945-9999-9-X",
            "9946-0-0000-X",
            "9946-1-9999-X",
            "9946-20-000-X",
            "9946-39-999-X",
            "9946-400-00-X",
            "9946-899-99-X",
            "9946-9000-0-X",
            "9946-9999-9-X",
            "9947-0-0000-X",
            "9947-1-9999-X",
            "9947-20-000-X",
            "9947-79-999-X",
            "9947-800-00-X",
            "9947-999-99-X",
            "9948-00-000-X",
            "9948-39-999-X",
            "9948-400-00-X",
            "9948-849-99-X",
            "9948-8500-0-X",
            "9948-9999-9-X",
            "9949-0-0000-X",
            "9949-0-9999-X",
            "9949-10-000-X",
            "9949-39-999-X",
            "9949-400-00-X",
            "9949-899-99-X",
            "9949-9000-0-X",
            "9949-9999-9-X",
            "9950-00-000-X",
            "9950-29-999-X",
            "9950-300-00-X",
            "9950-849-99-X",
            "9950-8500-0-X",
            "9950-9999-9-X",
            "9951-00-000-X",
            "9951-39-999-X",
            "9951-400-00-X",
            "9951-849-99-X",
            "9951-8500-0-X",
            "9951-9999-9-X",
            "9952-0-0000-X",
            "9952-1-9999-X",
            "9952-20-000-X",
            "9952-39-999-X",
            "9952-400-00-X",
            "9952-799-99-X",
            "9952-8000-0-X",
            "9952-9999-9-X",
            "9953-0-0000-X",
            "9953-0-9999-X",
            "9953-10-000-X",
            "9953-39-999-X",
            "9953-400-00-X",
            "9953-599-99-X",
            "9953-60-000-X",
            "9953-89-999-X",
            "9953-9000-0-X",
            "9953-9999-9-X",
            "9954-0-0000-X",
            "9954-1-9999-X",
            "9954-20-000-X",
            "9954-39-999-X",
            "9954-400-00-X",
            "9954-799-99-X",
            "9954-8000-0-X",
            "9954-9999-9-X",
            "9955-00-000-X",
            "9955-39-999-X",
            "9955-400-00-X",
            "9955-929-99-X",
            "9955-9300-0-X",
            "9955-9999-9-X",
            "9956-0-0000-X",
            "9956-0-9999-X",
            "9956-10-000-X",
            "9956-39-999-X",
            "9956-400-00-X",
            "9956-899-99-X",
            "9956-9000-0-X",
            "9956-9999-9-X",
            "9957-00-000-X",
            "9957-39-999-X",
            "9957-400-00-X",
            "9957-699-99-X",
            "9957-70-000-X",
            "9957-84-999-X",
            "9957-8500-0-X",
            "9957-8799-9-X",
            "9957-88-000-X",
            "9957-99-999-X",
            "9958-00-000-X",
            "9958-03-999-X",
            "9958-040-00-X",
            "9958-089-99-X",
            "9958-0900-0-X",
            "9958-0999-9-X",
            "9958-10-000-X",
            "9958-18-999-X",
            "9958-1900-0-X",
            "9958-1999-9-X",
            "9958-20-000-X",
            "9958-49-999-X",
            "9958-500-00-X",
            "9958-899-99-X",
            "9958-9000-0-X",
            "9958-9999-9-X",
            "9959-0-0000-X",
            "9959-1-9999-X",
            "9959-20-000-X",
            "9959-79-999-X",
            "9959-800-00-X",
            "9959-949-99-X",
            "9959-9500-0-X",
            "9959-9699-9-X",
            "9959-970-00-X",
            "9959-979-99-X",
            "9959-98-000-X",
            "9959-99-999-X",
            "9960-00-000-X",
            "9960-59-999-X",
            "9960-600-00-X",
            "9960-899-99-X",
            "9960-9000-0-X",
            "9960-9999-9-X",
            "9961-0-0000-X",
            "9961-2-9999-X",
            "9961-30-000-X",
            "9961-69-999-X",
            "9961-700-00-X",
            "9961-949-99-X",
            "9961-9500-0-X",
            "9961-9999-9-X",
            "9962-00-000-X",
            "9962-54-999-X",
            "9962-5500-0-X",
            "9962-5599-9-X",
            "9962-56-000-X",
            "9962-59-999-X",
            "9962-600-00-X",
            "9962-849-99-X",
            "9962-8500-0-X",
            "9962-9999-9-X",
            "9963-0-0000-X",
            "9963-1-9999-X",
            "9963-20-000-X",
            "9963-24-999-X",
            "9963-250-00-X",
            "9963-279-99-X",
            "9963-2800-0-X",
            "9963-2999-9-X",
            "9963-30-000-X",
            "9963-54-999-X",
            "9963-550-00-X",
            "9963-734-99-X",
            "9963-7350-0-X",
            "9963-7499-9-X",
            "9963-7500-0-X",
            "9963-9999-9-X",
            "9964-0-0000-X",
            "9964-6-9999-X",
            "9964-70-000-X",
            "9964-94-999-X",
            "9964-950-00-X",
            "9964-999-99-X",
            "9965-00-000-X",
            "9965-39-999-X",
            "9965-400-00-X",
            "9965-899-99-X",
            "9965-9000-0-X",
            "9965-9999-9-X",
            "9966-000-00-X",
            "9966-149-99-X",
            "9966-1500-0-X",
            "9966-1999-9-X",
            "9966-20-000-X",
            "9966-69-999-X",
            "9966-7000-0-X",
            "9966-7499-9-X",
            "9966-750-00-X",
            "9966-959-99-X",
            "9966-9600-0-X",
            "9966-9999-9-X",
            "9967-00-000-X",
            "9967-39-999-X",
            "9967-400-00-X",
            "9967-899-99-X",
            "9967-9000-0-X",
            "9967-9999-9-X",
            "9968-00-000-X",
            "9968-49-999-X",
            "9968-500-00-X",
            "9968-939-99-X",
            "9968-9400-0-X",
            "9968-9999-9-X",
            "9970-00-000-X",
            "9970-39-999-X",
            "9970-400-00-X",
            "9970-899-99-X",
            "9970-9000-0-X",
            "9970-9999-9-X",
            "9971-0-0000-X",
            "9971-5-9999-X",
            "9971-60-000-X",
            "9971-89-999-X",
            "9971-900-00-X",
            "9971-989-99-X",
            "9971-9900-0-X",
            "9971-9999-9-X",
            "9972-00-000-X",
            "9972-09-999-X",
            "9972-1-0000-X",
            "9972-1-9999-X",
            "9972-200-00-X",
            "9972-249-99-X",
            "9972-2500-0-X",
            "9972-2999-9-X",
            "9972-30-000-X",
            "9972-59-999-X",
            "9972-600-00-X",
            "9972-899-99-X",
            "9972-9000-0-X",
            "9972-9999-9-X",
            "9973-00-000-X",
            "9973-05-999-X",
            "9973-060-00-X",
            "9973-089-99-X",
            "9973-0900-0-X",
            "9973-0999-9-X",
            "9973-10-000-X",
            "9973-69-999-X",
            "9973-700-00-X",
            "9973-969-99-X",
            "9973-9700-0-X",
            "9973-9999-9-X",
            "9974-0-0000-X",
            "9974-2-9999-X",
            "9974-30-000-X",
            "9974-54-999-X",
            "9974-550-00-X",
            "9974-749-99-X",
            "9974-7500-0-X",
            "9974-9499-9-X",
            "9974-95-000-X",
            "9974-99-999-X",
            "9975-0-0000-X",
            "9975-0-9999-X",
            "9975-100-00-X",
            "9975-399-99-X",
            "9975-4000-0-X",
            "9975-4499-9-X",
            "9975-45-000-X",
            "9975-89-999-X",
            "9975-900-00-X",
            "9975-949-99-X",
            "9975-9500-0-X",
            "9975-9999-9-X",
            "9976-0-0000-X",
            "9976-5-9999-X",
            "9976-60-000-X",
            "9976-89-999-X",
            "9976-900-00-X",
            "9976-989-99-X",
            "9976-9900-0-X",
            "9976-9999-9-X",
            "9977-00-000-X",
            "9977-89-999-X",
            "9977-900-00-X",
            "9977-989-99-X",
            "9977-9900-0-X",
            "9977-9999-9-X",
            "9978-00-000-X",
            "9978-29-999-X",
            "9978-300-00-X",
            "9978-399-99-X",
            "9978-40-000-X",
            "9978-94-999-X",
            "9978-950-00-X",
            "9978-989-99-X",
            "9978-9900-0-X",
            "9978-9999-9-X",
            "9979-0-0000-X",
            "9979-4-9999-X",
            "9979-50-000-X",
            "9979-64-999-X",
            "9979-650-00-X",
            "9979-659-99-X",
            "9979-66-000-X",
            "9979-75-999-X",
            "9979-760-00-X",
            "9979-899-99-X",
            "9979-9000-0-X",
            "9979-9999-9-X",
            "9980-0-0000-X",
            "9980-3-9999-X",
            "9980-40-000-X",
            "9980-89-999-X",
            "9980-900-00-X",
            "9980-989-99-X",
            "9980-9900-0-X",
            "9980-9999-9-X",
            "9981-00-000-X",
            "9981-09-999-X",
            "9981-100-00-X",
            "9981-159-99-X",
            "9981-1600-0-X",
            "9981-1999-9-X",
            "9981-20-000-X",
            "9981-79-999-X",
            "9981-800-00-X",
            "9981-949-99-X",
            "9981-9500-0-X",
            "9981-9999-9-X",
            "9982-00-000-X",
            "9982-79-999-X",
            "9982-800-00-X",
            "9982-989-99-X",
            "9982-9900-0-X",
            "9982-9999-9-X",
            "9983-80-000-X",
            "9983-94-999-X",
            "9983-950-00-X",
            "9983-989-99-X",
            "9983-9900-0-X",
            "9983-9999-9-X",
            "9984-00-000-X",
            "9984-49-999-X",
            "9984-500-00-X",
            "9984-899-99-X",
            "9984-9000-0-X",
            "9984-9999-9-X",
            "9985-0-0000-X",
            "9985-4-9999-X",
            "9985-50-000-X",
            "9985-79-999-X",
            "9985-800-00-X",
            "9985-899-99-X",
            "9985-9000-0-X",
            "9985-9999-9-X",
            "9986-00-000-X",
            "9986-39-999-X",
            "9986-400-00-X",
            "9986-899-99-X",
            "9986-9000-0-X",
            "9986-9399-9-X",
            "9986-940-00-X",
            "9986-969-99-X",
            "9986-97-000-X",
            "9986-99-999-X",
            "9987-00-000-X",
            "9987-39-999-X",
            "9987-400-00-X",
            "9987-879-99-X",
            "9987-8800-0-X",
            "9987-9999-9-X",
            "9988-0-0000-X",
            "9988-2-9999-X",
            "9988-30-000-X",
            "9988-54-999-X",
            "9988-550-00-X",
            "9988-749-99-X",
            "9988-7500-0-X",
            "9988-9999-9-X",
            "9989-0-0000-X",
            "9989-0-9999-X",
            "9989-100-00-X",
            "9989-199-99-X",
            "9989-2000-0-X",
            "9989-2999-9-X",
            "9989-30-000-X",
            "9989-59-999-X",
            "9989-600-00-X",
            "9989-949-99-X",
            "9989-9500-0-X",
            "9989-9999-9-X",
            "99901-00-00-X",
            "99901-49-99-X",
            "99901-500-0-X",
            "99901-799-9-X",
            "99901-80-00-X",
            "99901-99-99-X",
            "99903-0-000-X",
            "99903-1-999-X",
            "99903-20-00-X",
            "99903-89-99-X",
            "99903-900-0-X",
            "99903-999-9-X",
            "99904-0-000-X",
            "99904-5-999-X",
            "99904-60-00-X",
            "99904-89-99-X",
            "99904-900-0-X",
            "99904-999-9-X",
            "99905-0-000-X",
            "99905-3-999-X",
            "99905-40-00-X",
            "99905-79-99-X",
            "99905-800-0-X",
            "99905-999-9-X",
            "99906-0-000-X",
            "99906-2-999-X",
            "99906-30-00-X",
            "99906-59-99-X",
            "99906-600-0-X",
            "99906-699-9-X",
            "99906-70-00-X",
            "99906-89-99-X",
            "99906-90-00-X",
            "99906-94-99-X",
            "99906-950-0-X",
            "99906-999-9-X",
            "99908-0-000-X",
            "99908-0-999-X",
            "99908-10-00-X",
            "99908-89-99-X",
            "99908-900-0-X",
            "99908-999-9-X",
            "99909-0-000-X",
            "99909-3-999-X",
            "99909-40-00-X",
            "99909-94-99-X",
            "99909-950-0-X",
            "99909-999-9-X",
            "99910-0-000-X",
            "99910-2-999-X",
            "99910-30-00-X",
            "99910-89-99-X",
            "99910-900-0-X",
            "99910-999-9-X",
            "99911-00-00-X",
            "99911-59-99-X",
            "99911-600-0-X",
            "99911-999-9-X",
            "99912-0-000-X",
            "99912-3-999-X",
            "99912-400-0-X",
            "99912-599-9-X",
            "99912-60-00-X",
            "99912-89-99-X",
            "99912-900-0-X",
            "99912-999-9-X",
            "99913-0-000-X",
            "99913-2-999-X",
            "99913-30-00-X",
            "99913-35-99-X",
            "99913-600-0-X",
            "99913-604-9-X",
            "99914-0-000-X",
            "99914-4-999-X",
            "99914-50-00-X",
            "99914-89-99-X",
            "99914-900-0-X",
            "99914-999-9-X",
            "99915-0-000-X",
            "99915-4-999-X",
            "99915-50-00-X",
            "99915-79-99-X",
            "99915-800-0-X",
            "99915-999-9-X",
            "99916-0-000-X",
            "99916-2-999-X",
            "99916-30-00-X",
            "99916-69-99-X",
            "99916-700-0-X",
            "99916-999-9-X",
            "99917-0-000-X",
            "99917-2-999-X",
            "99917-30-00-X",
            "99917-89-99-X",
            "99917-900-0-X",
            "99917-999-9-X",
            "99918-0-000-X",
            "99918-3-999-X",
            "99918-40-00-X",
            "99918-79-99-X",
            "99918-800-0-X",
            "99918-999-9-X",
            "99919-0-000-X",
            "99919-2-999-X",
            "99919-300-0-X",
            "99919-399-9-X",
            "99919-40-00-X",
            "99919-69-99-X",
            "99919-70-00-X",
            "99919-79-99-X",
            "99919-800-0-X",
            "99919-849-9-X",
            "99919-850-0-X",
            "99919-899-9-X",
            "99919-900-0-X",
            "99919-999-9-X",
            "99920-0-000-X",
            "99920-4-999-X",
            "99920-50-00-X",
            "99920-89-99-X",
            "99920-900-0-X",
            "99920-999-9-X",
            "99921-0-000-X",
            "99921-1-999-X",
            "99921-20-00-X",
            "99921-69-99-X",
            "99921-700-0-X",
            "99921-799-9-X",
            "99921-8-000-X",
            "99921-8-999-X",
            "99921-90-00-X",
            "99921-99-99-X",
            "99922-0-000-X",
            "99922-3-999-X",
            "99922-40-00-X",
            "99922-69-99-X",
            "99922-700-0-X",
            "99922-999-9-X",
            "99923-0-000-X",
            "99923-1-999-X",
            "99923-20-00-X",
            "99923-79-99-X",
            "99923-800-0-X",
            "99923-999-9-X",
            "99924-0-000-X",
            "99924-1-999-X",
            "99924-20-00-X",
            "99924-79-99-X",
            "99924-800-0-X",
            "99924-999-9-X",
            "99925-0-000-X",
            "99925-3-999-X",
            "99925-40-00-X",
            "99925-79-99-X",
            "99925-800-0-X",
            "99925-999-9-X",
            "99926-0-000-X",
            "99926-0-999-X",
            "99926-10-00-X",
            "99926-59-99-X",
            "99926-600-0-X",
            "99926-899-9-X",
            "99926-90-00-X",
            "99926-99-99-X",
            "99927-0-000-X",
            "99927-2-999-X",
            "99927-30-00-X",
            "99927-59-99-X",
            "99927-600-0-X",
            "99927-999-9-X",
            "99928-0-000-X",
            "99928-0-999-X",
            "99928-10-00-X",
            "99928-79-99-X",
            "99928-800-0-X",
            "99928-999-9-X",
            "99929-0-000-X",
            "99929-4-999-X",
            "99929-50-00-X",
            "99929-79-99-X",
            "99929-800-0-X",
            "99929-999-9-X",
            "99930-0-000-X",
            "99930-4-999-X",
            "99930-50-00-X",
            "99930-79-99-X",
            "99930-800-0-X",
            "99930-999-9-X",
            "99931-0-000-X",
            "99931-4-999-X",
            "99931-50-00-X",
            "99931-79-99-X",
            "99931-800-0-X",
            "99931-999-9-X",
            "99932-0-000-X",
            "99932-0-999-X",
            "99932-10-00-X",
            "99932-59-99-X",
            "99932-600-0-X",
            "99932-699-9-X",
            "99932-7-000-X",
            "99932-7-999-X",
            "99932-80-00-X",
            "99932-99-99-X",
            "99933-0-000-X",
            "99933-2-999-X",
            "99933-30-00-X",
            "99933-59-99-X",
            "99933-600-0-X",
            "99933-999-9-X",
            "99934-0-000-X",
            "99934-1-999-X",
            "99934-20-00-X",
            "99934-79-99-X",
            "99934-800-0-X",
            "99934-999-9-X",
            "99935-0-000-X",
            "99935-2-999-X",
            "99935-30-00-X",
            "99935-59-99-X",
            "99935-600-0-X",
            "99935-699-9-X",
            "99935-7-000-X",
            "99935-8-999-X",
            "99935-90-00-X",
            "99935-99-99-X",
            "99936-0-000-X",
            "99936-0-999-X",
            "99936-10-00-X",
            "99936-59-99-X",
            "99936-600-0-X",
            "99936-999-9-X",
            "99937-0-000-X",
            "99937-1-999-X",
            "99937-20-00-X",
            "99937-59-99-X",
            "99937-600-0-X",
            "99937-999-9-X",
            "99938-0-000-X",
            "99938-1-999-X",
            "99938-20-00-X",
            "99938-59-99-X",
            "99938-600-0-X",
            "99938-899-9-X",
            "99938-90-00-X",
            "99938-99-99-X",
            "99939-0-000-X",
            "99939-5-999-X",
            "99939-60-00-X",
            "99939-89-99-X",
            "99939-900-0-X",
            "99939-999-9-X",
            "99940-0-000-X",
            "99940-0-999-X",
            "99940-10-00-X",
            "99940-69-99-X",
            "99940-700-0-X",
            "99940-999-9-X",
            "99941-0-000-X",
            "99941-2-999-X",
            "99941-30-00-X",
            "99941-79-99-X",
            "99941-800-0-X",
            "99941-999-9-X",
            "99942-0-000-X",
            "99942-4-999-X",
            "99942-50-00-X",
            "99942-79-99-X",
            "99942-800-0-X",
            "99942-999-9-X",
            "99943-0-000-X",
            "99943-2-999-X",
            "99943-30-00-X",
            "99943-59-99-X",
            "99943-600-0-X",
            "99943-999-9-X",
            "99944-0-000-X",
            "99944-4-999-X",
            "99944-50-00-X",
            "99944-79-99-X",
            "99944-800-0-X",
            "99944-999-9-X",
            "99945-0-000-X",
            "99945-5-999-X",
            "99945-60-00-X",
            "99945-89-99-X",
            "99945-900-0-X",
            "99945-999-9-X",
            "99946-0-000-X",
            "99946-2-999-X",
            "99946-30-00-X",
            "99946-59-99-X",
            "99946-600-0-X",
            "99946-999-9-X",
            "99947-0-000-X",
            "99947-2-999-X",
            "99947-30-00-X",
            "99947-69-99-X",
            "99947-700-0-X",
            "99947-959-9-X",
            "99947-96-00-X",
            "99947-99-99-X",
            "99948-0-000-X",
            "99948-4-999-X",
            "99948-50-00-X",
            "99948-79-99-X",
            "99948-800-0-X",
            "99948-999-9-X",
            "99949-0-000-X",
            "99949-1-999-X",
            "99949-20-00-X",
            "99949-89-99-X",
            "99949-900-0-X",
            "99949-999-9-X",
            "99950-0-000-X",
            "99950-4-999-X",
            "99950-50-00-X",
            "99950-79-99-X",
            "99950-800-0-X",
            "99950-999-9-X",
            "99952-0-000-X",
            "99952-4-999-X",
            "99952-50-00-X",
            "99952-79-99-X",
            "99952-800-0-X",
            "99952-999-9-X",
            "99953-0-000-X",
            "99953-2-999-X",
            "99953-30-00-X",
            "99953-79-99-X",
            "99953-800-0-X",
            "99953-939-9-X",
            "99953-94-00-X",
            "99953-99-99-X",
            "99954-0-000-X",
            "99954-2-999-X",
            "99954-30-00-X",
            "99954-69-99-X",
            "99954-700-0-X",
            "99954-879-9-X",
            "99954-88-00-X",
            "99954-99-99-X",
            "99955-0-000-X",
            "99955-0-999-X",
            "99955-10-00-X",
            "99955-19-99-X",
            "99955-20-00-X",
            "99955-59-99-X",
            "99955-600-0-X",
            "99955-799-9-X",
            "99955-80-00-X",
            "99955-89-99-X",
            "99955-90-00-X",
            "99955-99-99-X",
            "99956-00-00-X",
            "99956-59-99-X",
            "99956-600-0-X",
            "99956-859-9-X",
            "99956-86-00-X",
            "99956-99-99-X",
            "99957-0-000-X",
            "99957-1-999-X",
            "99957-20-00-X",
            "99957-79-99-X",
            "99957-800-0-X",
            "99957-999-9-X",
            "99958-0-000-X",
            "99958-4-999-X",
            "99958-50-00-X",
            "99958-94-99-X",
            "99958-950-0-X",
            "99958-999-9-X",
            "99959-0-000-X",
            "99959-2-999-X",
            "99959-30-00-X",
            "99959-59-99-X",
            "99959-600-0-X",
            "99959-999-9-X",
            "99960-0-000-X",
            "99960-0-999-X",
            "99960-10-00-X",
            "99960-94-99-X",
            "99960-950-0-X",
            "99960-999-9-X",
            "99961-0-000-X",
            "99961-3-999-X",
            "99961-40-00-X",
            "99961-89-99-X",
            "99961-900-0-X",
            "99961-999-9-X",
            "99962-0-000-X",
            "99962-4-999-X",
            "99962-50-00-X",
            "99962-79-99-X",
            "99962-800-0-X",
            "99962-999-9-X",
            "99963-00-00-X",
            "99963-49-99-X",
            "99963-500-0-X",
            "99963-999-9-X",
            "99964-0-000-X",
            "99964-1-999-X",
            "99964-20-00-X",
            "99964-79-99-X",
            "99964-800-0-X",
            "99964-999-9-X",
            "99965-0-000-X",
            "99965-3-999-X",
            "99965-40-00-X",
            "99965-79-99-X",
            "99965-800-0-X",
            "99965-999-9-X",
            "99966-0-000-X",
            "99966-2-999-X",
            "99966-30-00-X",
            "99966-69-99-X",
            "99966-700-0-X",
            "99966-799-9-X",
            "99967-0-000-X",
            "99967-1-999-X",
            "99967-20-00-X",
            "99967-59-99-X",
            "99967-600-0-X",
            "99967-899-9-X",
            "99968-0-000-X",
            "99968-3-999-X",
            "99968-400-0-X",
            "99968-599-9-X",
            "99968-60-00-X",
            "99968-89-99-X",
            "99968-900-0-X",
            "99968-999-9-X",
            "99969-0-000-X",
            "99969-4-999-X",
            "99969-50-00-X",
            "99969-79-99-X",
            "99969-800-0-X",
            "99969-999-9-X",
            "99970-0-000-X",
            "99970-4-999-X",
            "99970-50-00-X",
            "99970-89-99-X",
            "99970-900-0-X",
            "99970-999-9-X",
            "99971-0-000-X",
            "99971-5-999-X",
            "99971-60-00-X",
            "99971-84-99-X",
            "99971-850-0-X",
            "99971-999-9-X",
            "99972-0-000-X",
            "99972-4-999-X",
            "99972-50-00-X",
            "99972-89-99-X",
            "99972-900-0-X",
            "99972-999-9-X",
            "99973-0-000-X",
            "99973-3-999-X",
            "99973-40-00-X",
            "99973-79-99-X",
            "99973-800-0-X",
            "99973-999-9-X",};

        this.ISBNHyphenAppender = new ISBNHyphenAppender();
    }

    /**
     * Test of {@code appendHyphenToISBN10} method, of class
     * {@code ISBNHyphenAppender}.
     * @deprecated 
     */
    @Test
    @Deprecated
    public void testAppendHyphenToISBN10() {
        //Checks if the method throws the exceptions

        //Checks if the ISBN is null. Must throw a NullPointerException
        try {
            this.ISBNHyphenAppender.appendHyphenToISBN10(null);
            Assert.fail("Must throw a NullPointerException");
        } catch (Exception ex) {
            Assert.assertEquals(NullPointerException.class, ex.getClass());
        }

        //Checks if the length of the ISBN is 10. Must throw an
        //IllegalArgumentException
        //Test with length 9
        try {
            String ISBNToTest = "000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN10(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }
        //Test with length 11
        try {
            String ISBNToTest = "00000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN10(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }

        //Checks if the ISBN is from an implemented group. Must throw an
        //UnsupportedOperationException
        try {
            String ISBNToTest = "aa00000000";
            this.ISBNHyphenAppender.appendHyphenToISBN10(ISBNToTest);
            Assert.fail("Must throw an UnsupportedOperationException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(UnsupportedOperationException.class, ex.getClass());
        }

        //Check if the method works well
        int length = this.ISBN10s.length;
        for (int i = 0; i < length; i++) {
            String ISBN10 = this.ISBN10s[i];

            String result = this.ISBNHyphenAppender.appendHyphenToISBN10(ISBN10.replaceAll("-", ""));
            Assert.assertEquals("Error in conversion of: " + ISBN10, ISBN10, result);
        }
    }

    /**
     * Test of {@code appendHyphenToISBN13} method, of class
     * {@code ISBNHyphenAppender}.
     * @deprecated 
     */
    @Test
    @Deprecated
    public void testAppendHyphenToISBN13() {
        //Checks if the method throws the exceptions

        //Checks if the ISBN-13 is null. Must throw a NullPointerException
        try {
            this.ISBNHyphenAppender.appendHyphenToISBN13(null);
            Assert.fail("Must throw a NullPointerException");
        } catch (Exception ex) {
            Assert.assertEquals(NullPointerException.class, ex.getClass());
        }

        //Checks if the length of the ISBN-13 is 10. Must throw an
        //IllegalArgumentException
        //Test with length 12
        try {
            String ISBNToTest = "000000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }
        //Test with length 14
        try {
            String ISBNToTest = "00000000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }

        //Checks if the length of the ISBN is 10. Must throw an
        //IllegalArgumentException
        //Test with length 9
        try {
            String ISBNToTest = "000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }
        //Test with length 11
        try {
            String ISBNToTest = "00000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }

        //Checks if the ISBN is from an implemented group. Must throw an
        //UnsupportedOperationException
        try {
            String ISBNToTest = "000aa00000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an UnsupportedOperationException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(UnsupportedOperationException.class, ex.getClass());
        }

        //Check if the method works well
        int length = this.ISBN13s.length;
        for (int i = 0; i < length; i++) {
            String ISBN13 = this.ISBN13s[i];

            String result = this.ISBNHyphenAppender.appendHyphenToISBN(ISBN13.replaceAll("-", ""));
            Assert.assertEquals("Error in conversion of: " + ISBN13, ISBN13, result);
        }
    }

    /**
     * Test of {@code appendHyphenToISBN} method, of class
     * {@code ISBNHyphenAppender}.
     */
    @Test
    public void testAppendHyphenToISBN() {
        //Checks if the method throws the exceptions

        //Checks if the ISBN is null. Must throw a NullPointerException
        try {
            this.ISBNHyphenAppender.appendHyphenToISBN(null);
            Assert.fail("Must throw a NullPointerException");
        } catch (Exception ex) {
            Assert.assertEquals(NullPointerException.class, ex.getClass());
        }

        //Checks if the length of the ISBN-13 is 10. Must throw an
        //IllegalArgumentException
        //Test with length 12
        try {
            String ISBNToTest = "000000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }
        //Test with length 14
        try {
            String ISBNToTest = "00000000000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an IllegalArgumentException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(IllegalArgumentException.class, ex.getClass());
        }

        //Checks if the ISBN is from an implemented group. Must throw an
        //UnsupportedOperationException
        try {
            String ISBNToTest = "000aa00000000";
            this.ISBNHyphenAppender.appendHyphenToISBN(ISBNToTest);
            Assert.fail("Must throw an UnsupportedOperationException for the ISBN: " + ISBNToTest);
        } catch (Exception ex) {
            Assert.assertEquals(UnsupportedOperationException.class, ex.getClass());
        }

        //Check if the method works well for ISBN-13
        int length = this.ISBN13s.length;
        for (int i = 0; i < length; i++) {
            String ISBN13 = this.ISBN13s[i];

            String result = this.ISBNHyphenAppender.appendHyphenToISBN(ISBN13.replaceAll("-", ""));
            Assert.assertEquals("Error in conversion of: " + ISBN13, ISBN13, result);
        }

        //Check if the method works well for ISBN-10
        length = this.ISBN10s.length;
        for (int i = 0; i < length; i++) {
            String ISBN10 = this.ISBN10s[i];

            String result = this.ISBNHyphenAppender.appendHyphenToISBN(ISBN10.replaceAll("-", ""));
            Assert.assertEquals("Error in conversion of: " + ISBN10, ISBN10, result);
        }
    }
}